import typing

import typing_extensions

_list = list

@typing.type_check_only
class GoogleCloudDatalabelingV1alpha1CreateInstructionMetadata(
    typing_extensions.TypedDict, total=False
):
    createTime: str
    instruction: str
    partialFailures: _list[GoogleRpcStatus]

@typing.type_check_only
class GoogleCloudDatalabelingV1alpha1ExportDataOperationMetadata(
    typing_extensions.TypedDict, total=False
):
    annotatedDataset: str
    createTime: str
    dataset: str
    partialFailures: _list[GoogleRpcStatus]

@typing.type_check_only
class GoogleCloudDatalabelingV1alpha1ExportDataOperationResponse(
    typing_extensions.TypedDict, total=False
):
    annotatedDataset: str
    dataset: str
    exportCount: int
    labelStats: GoogleCloudDatalabelingV1alpha1LabelStats
    outputConfig: GoogleCloudDatalabelingV1alpha1OutputConfig
    totalCount: int

@typing.type_check_only
class GoogleCloudDatalabelingV1alpha1GcsDestination(
    typing_extensions.TypedDict, total=False
):
    mimeType: str
    outputUri: str

@typing.type_check_only
class GoogleCloudDatalabelingV1alpha1GcsFolderDestination(
    typing_extensions.TypedDict, total=False
):
    outputFolderUri: str

@typing.type_check_only
class GoogleCloudDatalabelingV1alpha1HumanAnnotationConfig(
    typing_extensions.TypedDict, total=False
):
    annotatedDatasetDescription: str
    annotatedDatasetDisplayName: str
    contributorEmails: _list[str]
    instruction: str
    labelGroup: str
    languageCode: str
    questionDuration: str
    replicaCount: int
    userEmailAddress: str

@typing.type_check_only
class GoogleCloudDatalabelingV1alpha1ImportDataOperationMetadata(
    typing_extensions.TypedDict, total=False
):
    createTime: str
    dataset: str
    partialFailures: _list[GoogleRpcStatus]

@typing.type_check_only
class GoogleCloudDatalabelingV1alpha1ImportDataOperationResponse(
    typing_extensions.TypedDict, total=False
):
    dataset: str
    importCount: int
    totalCount: int

@typing.type_check_only
class GoogleCloudDatalabelingV1alpha1LabelImageBoundingBoxOperationMetadata(
    typing_extensions.TypedDict, total=False
):
    basicConfig: GoogleCloudDatalabelingV1alpha1HumanAnnotationConfig

@typing.type_check_only
class GoogleCloudDatalabelingV1alpha1LabelImageBoundingPolyOperationMetadata(
    typing_extensions.TypedDict, total=False
):
    basicConfig: GoogleCloudDatalabelingV1alpha1HumanAnnotationConfig

@typing.type_check_only
class GoogleCloudDatalabelingV1alpha1LabelImageClassificationOperationMetadata(
    typing_extensions.TypedDict, total=False
):
    basicConfig: GoogleCloudDatalabelingV1alpha1HumanAnnotationConfig

@typing.type_check_only
class GoogleCloudDatalabelingV1alpha1LabelImageOrientedBoundingBoxOperationMetadata(
    typing_extensions.TypedDict, total=False
):
    basicConfig: GoogleCloudDatalabelingV1alpha1HumanAnnotationConfig

@typing.type_check_only
class GoogleCloudDatalabelingV1alpha1LabelImagePolylineOperationMetadata(
    typing_extensions.TypedDict, total=False
):
    basicConfig: GoogleCloudDatalabelingV1alpha1HumanAnnotationConfig

@typing.type_check_only
class GoogleCloudDatalabelingV1alpha1LabelImageSegmentationOperationMetadata(
    typing_extensions.TypedDict, total=False
):
    basicConfig: GoogleCloudDatalabelingV1alpha1HumanAnnotationConfig

@typing.type_check_only
class GoogleCloudDatalabelingV1alpha1LabelOperationMetadata(
    typing_extensions.TypedDict, total=False
):
    annotatedDataset: str
    createTime: str
    dataset: str
    imageBoundingBoxDetails: GoogleCloudDatalabelingV1alpha1LabelImageBoundingBoxOperationMetadata
    imageBoundingPolyDetails: GoogleCloudDatalabelingV1alpha1LabelImageBoundingPolyOperationMetadata
    imageClassificationDetails: GoogleCloudDatalabelingV1alpha1LabelImageClassificationOperationMetadata
    imageOrientedBoundingBoxDetails: GoogleCloudDatalabelingV1alpha1LabelImageOrientedBoundingBoxOperationMetadata
    imagePolylineDetails: GoogleCloudDatalabelingV1alpha1LabelImagePolylineOperationMetadata
    imageSegmentationDetails: GoogleCloudDatalabelingV1alpha1LabelImageSegmentationOperationMetadata
    partialFailures: _list[GoogleRpcStatus]
    progressPercent: int
    textClassificationDetails: GoogleCloudDatalabelingV1alpha1LabelTextClassificationOperationMetadata
    textEntityExtractionDetails: GoogleCloudDatalabelingV1alpha1LabelTextEntityExtractionOperationMetadata
    videoClassificationDetails: GoogleCloudDatalabelingV1alpha1LabelVideoClassificationOperationMetadata
    videoEventDetails: GoogleCloudDatalabelingV1alpha1LabelVideoEventOperationMetadata
    videoObjectDetectionDetails: GoogleCloudDatalabelingV1alpha1LabelVideoObjectDetectionOperationMetadata
    videoObjectTrackingDetails: GoogleCloudDatalabelingV1alpha1LabelVideoObjectTrackingOperationMetadata

@typing.type_check_only
class GoogleCloudDatalabelingV1alpha1LabelStats(
    typing_extensions.TypedDict, total=False
):
    exampleCount: dict[str, typing.Any]

@typing.type_check_only
class GoogleCloudDatalabelingV1alpha1LabelTextClassificationOperationMetadata(
    typing_extensions.TypedDict, total=False
):
    basicConfig: GoogleCloudDatalabelingV1alpha1HumanAnnotationConfig

@typing.type_check_only
class GoogleCloudDatalabelingV1alpha1LabelTextEntityExtractionOperationMetadata(
    typing_extensions.TypedDict, total=False
):
    basicConfig: GoogleCloudDatalabelingV1alpha1HumanAnnotationConfig

@typing.type_check_only
class GoogleCloudDatalabelingV1alpha1LabelVideoClassificationOperationMetadata(
    typing_extensions.TypedDict, total=False
):
    basicConfig: GoogleCloudDatalabelingV1alpha1HumanAnnotationConfig

@typing.type_check_only
class GoogleCloudDatalabelingV1alpha1LabelVideoEventOperationMetadata(
    typing_extensions.TypedDict, total=False
):
    basicConfig: GoogleCloudDatalabelingV1alpha1HumanAnnotationConfig

@typing.type_check_only
class GoogleCloudDatalabelingV1alpha1LabelVideoObjectDetectionOperationMetadata(
    typing_extensions.TypedDict, total=False
):
    basicConfig: GoogleCloudDatalabelingV1alpha1HumanAnnotationConfig

@typing.type_check_only
class GoogleCloudDatalabelingV1alpha1LabelVideoObjectTrackingOperationMetadata(
    typing_extensions.TypedDict, total=False
):
    basicConfig: GoogleCloudDatalabelingV1alpha1HumanAnnotationConfig

@typing.type_check_only
class GoogleCloudDatalabelingV1alpha1OutputConfig(
    typing_extensions.TypedDict, total=False
):
    gcsDestination: GoogleCloudDatalabelingV1alpha1GcsDestination
    gcsFolderDestination: GoogleCloudDatalabelingV1alpha1GcsFolderDestination

@typing.type_check_only
class GoogleCloudDatalabelingV1beta1AnnotatedDataset(
    typing_extensions.TypedDict, total=False
):
    annotationSource: typing_extensions.Literal[
        "ANNOTATION_SOURCE_UNSPECIFIED", "OPERATOR"
    ]
    annotationType: typing_extensions.Literal[
        "ANNOTATION_TYPE_UNSPECIFIED",
        "IMAGE_CLASSIFICATION_ANNOTATION",
        "IMAGE_BOUNDING_BOX_ANNOTATION",
        "IMAGE_ORIENTED_BOUNDING_BOX_ANNOTATION",
        "IMAGE_BOUNDING_POLY_ANNOTATION",
        "IMAGE_POLYLINE_ANNOTATION",
        "IMAGE_SEGMENTATION_ANNOTATION",
        "VIDEO_SHOTS_CLASSIFICATION_ANNOTATION",
        "VIDEO_OBJECT_TRACKING_ANNOTATION",
        "VIDEO_OBJECT_DETECTION_ANNOTATION",
        "VIDEO_EVENT_ANNOTATION",
        "TEXT_CLASSIFICATION_ANNOTATION",
        "TEXT_ENTITY_EXTRACTION_ANNOTATION",
        "GENERAL_CLASSIFICATION_ANNOTATION",
    ]
    blockingResources: _list[str]
    completedExampleCount: str
    createTime: str
    description: str
    displayName: str
    exampleCount: str
    labelStats: GoogleCloudDatalabelingV1beta1LabelStats
    metadata: GoogleCloudDatalabelingV1beta1AnnotatedDatasetMetadata
    name: str

@typing.type_check_only
class GoogleCloudDatalabelingV1beta1AnnotatedDatasetMetadata(
    typing_extensions.TypedDict, total=False
):
    boundingPolyConfig: GoogleCloudDatalabelingV1beta1BoundingPolyConfig
    eventConfig: GoogleCloudDatalabelingV1beta1EventConfig
    humanAnnotationConfig: GoogleCloudDatalabelingV1beta1HumanAnnotationConfig
    imageClassificationConfig: GoogleCloudDatalabelingV1beta1ImageClassificationConfig
    objectDetectionConfig: GoogleCloudDatalabelingV1beta1ObjectDetectionConfig
    objectTrackingConfig: GoogleCloudDatalabelingV1beta1ObjectTrackingConfig
    polylineConfig: GoogleCloudDatalabelingV1beta1PolylineConfig
    segmentationConfig: GoogleCloudDatalabelingV1beta1SegmentationConfig
    textClassificationConfig: GoogleCloudDatalabelingV1beta1TextClassificationConfig
    textEntityExtractionConfig: GoogleCloudDatalabelingV1beta1TextEntityExtractionConfig
    videoClassificationConfig: GoogleCloudDatalabelingV1beta1VideoClassificationConfig

@typing.type_check_only
class GoogleCloudDatalabelingV1beta1Annotation(
    typing_extensions.TypedDict, total=False
):
    annotationMetadata: GoogleCloudDatalabelingV1beta1AnnotationMetadata
    annotationSentiment: typing_extensions.Literal[
        "ANNOTATION_SENTIMENT_UNSPECIFIED", "NEGATIVE", "POSITIVE"
    ]
    annotationSource: typing_extensions.Literal[
        "ANNOTATION_SOURCE_UNSPECIFIED", "OPERATOR"
    ]
    annotationValue: GoogleCloudDatalabelingV1beta1AnnotationValue
    name: str

@typing.type_check_only
class GoogleCloudDatalabelingV1beta1AnnotationMetadata(
    typing_extensions.TypedDict, total=False
):
    operatorMetadata: GoogleCloudDatalabelingV1beta1OperatorMetadata

@typing.type_check_only
class GoogleCloudDatalabelingV1beta1AnnotationSpec(
    typing_extensions.TypedDict, total=False
):
    description: str
    displayName: str
    index: int

@typing.type_check_only
class GoogleCloudDatalabelingV1beta1AnnotationSpecSet(
    typing_extensions.TypedDict, total=False
):
    annotationSpecs: _list[GoogleCloudDatalabelingV1beta1AnnotationSpec]
    blockingResources: _list[str]
    description: str
    displayName: str
    name: str

@typing.type_check_only
class GoogleCloudDatalabelingV1beta1AnnotationSpecSetConfig(
    typing_extensions.TypedDict, total=False
):
    allowMultiLabel: bool
    annotationSpecSet: str

@typing.type_check_only
class GoogleCloudDatalabelingV1beta1AnnotationValue(
    typing_extensions.TypedDict, total=False
):
    imageBoundingPolyAnnotation: GoogleCloudDatalabelingV1beta1ImageBoundingPolyAnnotation
    imageClassificationAnnotation: GoogleCloudDatalabelingV1beta1ImageClassificationAnnotation
    imagePolylineAnnotation: GoogleCloudDatalabelingV1beta1ImagePolylineAnnotation
    imageSegmentationAnnotation: GoogleCloudDatalabelingV1beta1ImageSegmentationAnnotation
    textClassificationAnnotation: GoogleCloudDatalabelingV1beta1TextClassificationAnnotation
    textEntityExtractionAnnotation: GoogleCloudDatalabelingV1beta1TextEntityExtractionAnnotation
    videoClassificationAnnotation: GoogleCloudDatalabelingV1beta1VideoClassificationAnnotation
    videoEventAnnotation: GoogleCloudDatalabelingV1beta1VideoEventAnnotation
    videoObjectTrackingAnnotation: GoogleCloudDatalabelingV1beta1VideoObjectTrackingAnnotation

@typing.type_check_only
class GoogleCloudDatalabelingV1beta1Attempt(typing_extensions.TypedDict, total=False):
    attemptTime: str
    partialFailures: _list[GoogleRpcStatus]

@typing.type_check_only
class GoogleCloudDatalabelingV1beta1BigQuerySource(
    typing_extensions.TypedDict, total=False
):
    inputUri: str

@typing.type_check_only
class GoogleCloudDatalabelingV1beta1BoundingBoxEvaluationOptions(
    typing_extensions.TypedDict, total=False
):
    iouThreshold: float

@typing.type_check_only
class GoogleCloudDatalabelingV1beta1BoundingPoly(
    typing_extensions.TypedDict, total=False
):
    vertices: _list[GoogleCloudDatalabelingV1beta1Vertex]

@typing.type_check_only
class GoogleCloudDatalabelingV1beta1BoundingPolyConfig(
    typing_extensions.TypedDict, total=False
):
    annotationSpecSet: str
    instructionMessage: str

@typing.type_check_only
class GoogleCloudDatalabelingV1beta1ClassificationMetadata(
    typing_extensions.TypedDict, total=False
):
    isMultiLabel: bool

@typing.type_check_only
class GoogleCloudDatalabelingV1beta1ClassificationMetrics(
    typing_extensions.TypedDict, total=False
):
    confusionMatrix: GoogleCloudDatalabelingV1beta1ConfusionMatrix
    prCurve: GoogleCloudDatalabelingV1beta1PrCurve

@typing.type_check_only
class GoogleCloudDatalabelingV1beta1ConfidenceMetricsEntry(
    typing_extensions.TypedDict, total=False
):
    confidenceThreshold: float
    f1Score: float
    f1ScoreAt1: float
    f1ScoreAt5: float
    precision: float
    precisionAt1: float
    precisionAt5: float
    recall: float
    recallAt1: float
    recallAt5: float

@typing.type_check_only
class GoogleCloudDatalabelingV1beta1ConfusionMatrix(
    typing_extensions.TypedDict, total=False
):
    row: _list[GoogleCloudDatalabelingV1beta1Row]

@typing.type_check_only
class GoogleCloudDatalabelingV1beta1ConfusionMatrixEntry(
    typing_extensions.TypedDict, total=False
):
    annotationSpec: GoogleCloudDatalabelingV1beta1AnnotationSpec
    itemCount: int

@typing.type_check_only
class GoogleCloudDatalabelingV1beta1CreateAnnotationSpecSetRequest(
    typing_extensions.TypedDict, total=False
):
    annotationSpecSet: GoogleCloudDatalabelingV1beta1AnnotationSpecSet

@typing.type_check_only
class GoogleCloudDatalabelingV1beta1CreateDatasetRequest(
    typing_extensions.TypedDict, total=False
):
    dataset: GoogleCloudDatalabelingV1beta1Dataset

@typing.type_check_only
class GoogleCloudDatalabelingV1beta1CreateEvaluationJobRequest(
    typing_extensions.TypedDict, total=False
):
    job: GoogleCloudDatalabelingV1beta1EvaluationJob

@typing.type_check_only
class GoogleCloudDatalabelingV1beta1CreateInstructionMetadata(
    typing_extensions.TypedDict, total=False
):
    createTime: str
    instruction: str
    partialFailures: _list[GoogleRpcStatus]

@typing.type_check_only
class GoogleCloudDatalabelingV1beta1CreateInstructionRequest(
    typing_extensions.TypedDict, total=False
):
    instruction: GoogleCloudDatalabelingV1beta1Instruction

@typing.type_check_only
class GoogleCloudDatalabelingV1beta1CsvInstruction(
    typing_extensions.TypedDict, total=False
):
    gcsFileUri: str

@typing.type_check_only
class GoogleCloudDatalabelingV1beta1DataItem(typing_extensions.TypedDict, total=False):
    imagePayload: GoogleCloudDatalabelingV1beta1ImagePayload
    name: str
    textPayload: GoogleCloudDatalabelingV1beta1TextPayload
    videoPayload: GoogleCloudDatalabelingV1beta1VideoPayload

@typing.type_check_only
class GoogleCloudDatalabelingV1beta1Dataset(typing_extensions.TypedDict, total=False):
    blockingResources: _list[str]
    createTime: str
    dataItemCount: str
    description: str
    displayName: str
    inputConfigs: _list[GoogleCloudDatalabelingV1beta1InputConfig]
    lastMigrateTime: str
    name: str

@typing.type_check_only
class GoogleCloudDatalabelingV1beta1Evaluation(
    typing_extensions.TypedDict, total=False
):
    annotationType: typing_extensions.Literal[
        "ANNOTATION_TYPE_UNSPECIFIED",
        "IMAGE_CLASSIFICATION_ANNOTATION",
        "IMAGE_BOUNDING_BOX_ANNOTATION",
        "IMAGE_ORIENTED_BOUNDING_BOX_ANNOTATION",
        "IMAGE_BOUNDING_POLY_ANNOTATION",
        "IMAGE_POLYLINE_ANNOTATION",
        "IMAGE_SEGMENTATION_ANNOTATION",
        "VIDEO_SHOTS_CLASSIFICATION_ANNOTATION",
        "VIDEO_OBJECT_TRACKING_ANNOTATION",
        "VIDEO_OBJECT_DETECTION_ANNOTATION",
        "VIDEO_EVENT_ANNOTATION",
        "TEXT_CLASSIFICATION_ANNOTATION",
        "TEXT_ENTITY_EXTRACTION_ANNOTATION",
        "GENERAL_CLASSIFICATION_ANNOTATION",
    ]
    config: GoogleCloudDatalabelingV1beta1EvaluationConfig
    createTime: str
    evaluatedItemCount: str
    evaluationJobRunTime: str
    evaluationMetrics: GoogleCloudDatalabelingV1beta1EvaluationMetrics
    name: str

@typing.type_check_only
class GoogleCloudDatalabelingV1beta1EvaluationConfig(
    typing_extensions.TypedDict, total=False
):
    boundingBoxEvaluationOptions: GoogleCloudDatalabelingV1beta1BoundingBoxEvaluationOptions

@typing.type_check_only
class GoogleCloudDatalabelingV1beta1EvaluationJob(
    typing_extensions.TypedDict, total=False
):
    annotationSpecSet: str
    attempts: _list[GoogleCloudDatalabelingV1beta1Attempt]
    createTime: str
    description: str
    evaluationJobConfig: GoogleCloudDatalabelingV1beta1EvaluationJobConfig
    labelMissingGroundTruth: bool
    modelVersion: str
    name: str
    schedule: str
    state: typing_extensions.Literal[
        "STATE_UNSPECIFIED", "SCHEDULED", "RUNNING", "PAUSED", "STOPPED"
    ]

@typing.type_check_only
class GoogleCloudDatalabelingV1beta1EvaluationJobAlertConfig(
    typing_extensions.TypedDict, total=False
):
    email: str
    minAcceptableMeanAveragePrecision: float

@typing.type_check_only
class GoogleCloudDatalabelingV1beta1EvaluationJobConfig(
    typing_extensions.TypedDict, total=False
):
    bigqueryImportKeys: dict[str, typing.Any]
    boundingPolyConfig: GoogleCloudDatalabelingV1beta1BoundingPolyConfig
    evaluationConfig: GoogleCloudDatalabelingV1beta1EvaluationConfig
    evaluationJobAlertConfig: GoogleCloudDatalabelingV1beta1EvaluationJobAlertConfig
    exampleCount: int
    exampleSamplePercentage: float
    humanAnnotationConfig: GoogleCloudDatalabelingV1beta1HumanAnnotationConfig
    imageClassificationConfig: GoogleCloudDatalabelingV1beta1ImageClassificationConfig
    inputConfig: GoogleCloudDatalabelingV1beta1InputConfig
    textClassificationConfig: GoogleCloudDatalabelingV1beta1TextClassificationConfig

@typing.type_check_only
class GoogleCloudDatalabelingV1beta1EvaluationMetrics(
    typing_extensions.TypedDict, total=False
):
    classificationMetrics: GoogleCloudDatalabelingV1beta1ClassificationMetrics
    objectDetectionMetrics: GoogleCloudDatalabelingV1beta1ObjectDetectionMetrics

@typing.type_check_only
class GoogleCloudDatalabelingV1beta1EventConfig(
    typing_extensions.TypedDict, total=False
):
    annotationSpecSets: _list[str]
    clipLength: int
    overlapLength: int

@typing.type_check_only
class GoogleCloudDatalabelingV1beta1Example(typing_extensions.TypedDict, total=False):
    annotations: _list[GoogleCloudDatalabelingV1beta1Annotation]
    imagePayload: GoogleCloudDatalabelingV1beta1ImagePayload
    name: str
    textPayload: GoogleCloudDatalabelingV1beta1TextPayload
    videoPayload: GoogleCloudDatalabelingV1beta1VideoPayload

@typing.type_check_only
class GoogleCloudDatalabelingV1beta1ExampleComparison(
    typing_extensions.TypedDict, total=False
):
    groundTruthExample: GoogleCloudDatalabelingV1beta1Example
    modelCreatedExamples: _list[GoogleCloudDatalabelingV1beta1Example]

@typing.type_check_only
class GoogleCloudDatalabelingV1beta1ExportDataOperationMetadata(
    typing_extensions.TypedDict, total=False
):
    annotatedDataset: str
    createTime: str
    dataset: str
    partialFailures: _list[GoogleRpcStatus]

@typing.type_check_only
class GoogleCloudDatalabelingV1beta1ExportDataOperationResponse(
    typing_extensions.TypedDict, total=False
):
    annotatedDataset: str
    dataset: str
    exportCount: int
    labelStats: GoogleCloudDatalabelingV1beta1LabelStats
    outputConfig: GoogleCloudDatalabelingV1beta1OutputConfig
    totalCount: int

@typing.type_check_only
class GoogleCloudDatalabelingV1beta1ExportDataRequest(
    typing_extensions.TypedDict, total=False
):
    annotatedDataset: str
    filter: str
    outputConfig: GoogleCloudDatalabelingV1beta1OutputConfig
    userEmailAddress: str

@typing.type_check_only
class GoogleCloudDatalabelingV1beta1FeedbackMessage(
    typing_extensions.TypedDict, total=False
):
    body: str
    createTime: str
    image: str
    name: str
    operatorFeedbackMetadata: GoogleCloudDatalabelingV1beta1OperatorFeedbackMetadata
    requesterFeedbackMetadata: GoogleCloudDatalabelingV1beta1RequesterFeedbackMetadata

@typing.type_check_only
class GoogleCloudDatalabelingV1beta1FeedbackThread(
    typing_extensions.TypedDict, total=False
):
    feedbackThreadMetadata: GoogleCloudDatalabelingV1beta1FeedbackThreadMetadata
    name: str

@typing.type_check_only
class GoogleCloudDatalabelingV1beta1FeedbackThreadMetadata(
    typing_extensions.TypedDict, total=False
):
    createTime: str
    lastUpdateTime: str
    status: typing_extensions.Literal[
        "FEEDBACK_THREAD_STATUS_UNSPECIFIED", "NEW", "REPLIED"
    ]
    thumbnail: str

@typing.type_check_only
class GoogleCloudDatalabelingV1beta1GcsDestination(
    typing_extensions.TypedDict, total=False
):
    mimeType: str
    outputUri: str

@typing.type_check_only
class GoogleCloudDatalabelingV1beta1GcsFolderDestination(
    typing_extensions.TypedDict, total=False
):
    outputFolderUri: str

@typing.type_check_only
class GoogleCloudDatalabelingV1beta1GcsSource(typing_extensions.TypedDict, total=False):
    inputUri: str
    mimeType: str

@typing.type_check_only
class GoogleCloudDatalabelingV1beta1HumanAnnotationConfig(
    typing_extensions.TypedDict, total=False
):
    annotatedDatasetDescription: str
    annotatedDatasetDisplayName: str
    contributorEmails: _list[str]
    instruction: str
    labelGroup: str
    languageCode: str
    questionDuration: str
    replicaCount: int
    userEmailAddress: str

@typing.type_check_only
class GoogleCloudDatalabelingV1beta1ImageBoundingPolyAnnotation(
    typing_extensions.TypedDict, total=False
):
    annotationSpec: GoogleCloudDatalabelingV1beta1AnnotationSpec
    boundingPoly: GoogleCloudDatalabelingV1beta1BoundingPoly
    normalizedBoundingPoly: GoogleCloudDatalabelingV1beta1NormalizedBoundingPoly

@typing.type_check_only
class GoogleCloudDatalabelingV1beta1ImageClassificationAnnotation(
    typing_extensions.TypedDict, total=False
):
    annotationSpec: GoogleCloudDatalabelingV1beta1AnnotationSpec

@typing.type_check_only
class GoogleCloudDatalabelingV1beta1ImageClassificationConfig(
    typing_extensions.TypedDict, total=False
):
    allowMultiLabel: bool
    annotationSpecSet: str
    answerAggregationType: typing_extensions.Literal[
        "STRING_AGGREGATION_TYPE_UNSPECIFIED",
        "MAJORITY_VOTE",
        "UNANIMOUS_VOTE",
        "NO_AGGREGATION",
    ]

@typing.type_check_only
class GoogleCloudDatalabelingV1beta1ImagePayload(
    typing_extensions.TypedDict, total=False
):
    imageThumbnail: str
    imageUri: str
    mimeType: str
    signedUri: str

@typing.type_check_only
class GoogleCloudDatalabelingV1beta1ImagePolylineAnnotation(
    typing_extensions.TypedDict, total=False
):
    annotationSpec: GoogleCloudDatalabelingV1beta1AnnotationSpec
    normalizedPolyline: GoogleCloudDatalabelingV1beta1NormalizedPolyline
    polyline: GoogleCloudDatalabelingV1beta1Polyline

@typing.type_check_only
class GoogleCloudDatalabelingV1beta1ImageSegmentationAnnotation(
    typing_extensions.TypedDict, total=False
):
    annotationColors: dict[str, typing.Any]
    imageBytes: str
    mimeType: str

@typing.type_check_only
class GoogleCloudDatalabelingV1beta1ImportDataOperationMetadata(
    typing_extensions.TypedDict, total=False
):
    createTime: str
    dataset: str
    partialFailures: _list[GoogleRpcStatus]

@typing.type_check_only
class GoogleCloudDatalabelingV1beta1ImportDataOperationResponse(
    typing_extensions.TypedDict, total=False
):
    dataset: str
    importCount: int
    totalCount: int

@typing.type_check_only
class GoogleCloudDatalabelingV1beta1ImportDataRequest(
    typing_extensions.TypedDict, total=False
):
    inputConfig: GoogleCloudDatalabelingV1beta1InputConfig
    userEmailAddress: str

@typing.type_check_only
class GoogleCloudDatalabelingV1beta1InputConfig(
    typing_extensions.TypedDict, total=False
):
    annotationType: typing_extensions.Literal[
        "ANNOTATION_TYPE_UNSPECIFIED",
        "IMAGE_CLASSIFICATION_ANNOTATION",
        "IMAGE_BOUNDING_BOX_ANNOTATION",
        "IMAGE_ORIENTED_BOUNDING_BOX_ANNOTATION",
        "IMAGE_BOUNDING_POLY_ANNOTATION",
        "IMAGE_POLYLINE_ANNOTATION",
        "IMAGE_SEGMENTATION_ANNOTATION",
        "VIDEO_SHOTS_CLASSIFICATION_ANNOTATION",
        "VIDEO_OBJECT_TRACKING_ANNOTATION",
        "VIDEO_OBJECT_DETECTION_ANNOTATION",
        "VIDEO_EVENT_ANNOTATION",
        "TEXT_CLASSIFICATION_ANNOTATION",
        "TEXT_ENTITY_EXTRACTION_ANNOTATION",
        "GENERAL_CLASSIFICATION_ANNOTATION",
    ]
    bigquerySource: GoogleCloudDatalabelingV1beta1BigQuerySource
    classificationMetadata: GoogleCloudDatalabelingV1beta1ClassificationMetadata
    dataType: typing_extensions.Literal[
        "DATA_TYPE_UNSPECIFIED", "IMAGE", "VIDEO", "TEXT", "GENERAL_DATA"
    ]
    gcsSource: GoogleCloudDatalabelingV1beta1GcsSource
    textMetadata: GoogleCloudDatalabelingV1beta1TextMetadata

@typing.type_check_only
class GoogleCloudDatalabelingV1beta1Instruction(
    typing_extensions.TypedDict, total=False
):
    blockingResources: _list[str]
    createTime: str
    csvInstruction: GoogleCloudDatalabelingV1beta1CsvInstruction
    dataType: typing_extensions.Literal[
        "DATA_TYPE_UNSPECIFIED", "IMAGE", "VIDEO", "TEXT", "GENERAL_DATA"
    ]
    description: str
    displayName: str
    name: str
    pdfInstruction: GoogleCloudDatalabelingV1beta1PdfInstruction
    updateTime: str

@typing.type_check_only
class GoogleCloudDatalabelingV1beta1LabelImageBoundingBoxOperationMetadata(
    typing_extensions.TypedDict, total=False
):
    basicConfig: GoogleCloudDatalabelingV1beta1HumanAnnotationConfig

@typing.type_check_only
class GoogleCloudDatalabelingV1beta1LabelImageBoundingPolyOperationMetadata(
    typing_extensions.TypedDict, total=False
):
    basicConfig: GoogleCloudDatalabelingV1beta1HumanAnnotationConfig

@typing.type_check_only
class GoogleCloudDatalabelingV1beta1LabelImageClassificationOperationMetadata(
    typing_extensions.TypedDict, total=False
):
    basicConfig: GoogleCloudDatalabelingV1beta1HumanAnnotationConfig

@typing.type_check_only
class GoogleCloudDatalabelingV1beta1LabelImageOrientedBoundingBoxOperationMetadata(
    typing_extensions.TypedDict, total=False
):
    basicConfig: GoogleCloudDatalabelingV1beta1HumanAnnotationConfig

@typing.type_check_only
class GoogleCloudDatalabelingV1beta1LabelImagePolylineOperationMetadata(
    typing_extensions.TypedDict, total=False
):
    basicConfig: GoogleCloudDatalabelingV1beta1HumanAnnotationConfig

@typing.type_check_only
class GoogleCloudDatalabelingV1beta1LabelImageRequest(
    typing_extensions.TypedDict, total=False
):
    basicConfig: GoogleCloudDatalabelingV1beta1HumanAnnotationConfig
    boundingPolyConfig: GoogleCloudDatalabelingV1beta1BoundingPolyConfig
    feature: typing_extensions.Literal[
        "FEATURE_UNSPECIFIED",
        "CLASSIFICATION",
        "BOUNDING_BOX",
        "ORIENTED_BOUNDING_BOX",
        "BOUNDING_POLY",
        "POLYLINE",
        "SEGMENTATION",
    ]
    imageClassificationConfig: GoogleCloudDatalabelingV1beta1ImageClassificationConfig
    polylineConfig: GoogleCloudDatalabelingV1beta1PolylineConfig
    segmentationConfig: GoogleCloudDatalabelingV1beta1SegmentationConfig

@typing.type_check_only
class GoogleCloudDatalabelingV1beta1LabelImageSegmentationOperationMetadata(
    typing_extensions.TypedDict, total=False
):
    basicConfig: GoogleCloudDatalabelingV1beta1HumanAnnotationConfig

@typing.type_check_only
class GoogleCloudDatalabelingV1beta1LabelOperationMetadata(
    typing_extensions.TypedDict, total=False
):
    annotatedDataset: str
    createTime: str
    dataset: str
    imageBoundingBoxDetails: GoogleCloudDatalabelingV1beta1LabelImageBoundingBoxOperationMetadata
    imageBoundingPolyDetails: GoogleCloudDatalabelingV1beta1LabelImageBoundingPolyOperationMetadata
    imageClassificationDetails: GoogleCloudDatalabelingV1beta1LabelImageClassificationOperationMetadata
    imageOrientedBoundingBoxDetails: GoogleCloudDatalabelingV1beta1LabelImageOrientedBoundingBoxOperationMetadata
    imagePolylineDetails: GoogleCloudDatalabelingV1beta1LabelImagePolylineOperationMetadata
    imageSegmentationDetails: GoogleCloudDatalabelingV1beta1LabelImageSegmentationOperationMetadata
    partialFailures: _list[GoogleRpcStatus]
    progressPercent: int
    textClassificationDetails: GoogleCloudDatalabelingV1beta1LabelTextClassificationOperationMetadata
    textEntityExtractionDetails: GoogleCloudDatalabelingV1beta1LabelTextEntityExtractionOperationMetadata
    videoClassificationDetails: GoogleCloudDatalabelingV1beta1LabelVideoClassificationOperationMetadata
    videoEventDetails: GoogleCloudDatalabelingV1beta1LabelVideoEventOperationMetadata
    videoObjectDetectionDetails: GoogleCloudDatalabelingV1beta1LabelVideoObjectDetectionOperationMetadata
    videoObjectTrackingDetails: GoogleCloudDatalabelingV1beta1LabelVideoObjectTrackingOperationMetadata

@typing.type_check_only
class GoogleCloudDatalabelingV1beta1LabelStats(
    typing_extensions.TypedDict, total=False
):
    exampleCount: dict[str, typing.Any]

@typing.type_check_only
class GoogleCloudDatalabelingV1beta1LabelTextClassificationOperationMetadata(
    typing_extensions.TypedDict, total=False
):
    basicConfig: GoogleCloudDatalabelingV1beta1HumanAnnotationConfig

@typing.type_check_only
class GoogleCloudDatalabelingV1beta1LabelTextEntityExtractionOperationMetadata(
    typing_extensions.TypedDict, total=False
):
    basicConfig: GoogleCloudDatalabelingV1beta1HumanAnnotationConfig

@typing.type_check_only
class GoogleCloudDatalabelingV1beta1LabelTextRequest(
    typing_extensions.TypedDict, total=False
):
    basicConfig: GoogleCloudDatalabelingV1beta1HumanAnnotationConfig
    feature: typing_extensions.Literal[
        "FEATURE_UNSPECIFIED", "TEXT_CLASSIFICATION", "TEXT_ENTITY_EXTRACTION"
    ]
    textClassificationConfig: GoogleCloudDatalabelingV1beta1TextClassificationConfig
    textEntityExtractionConfig: GoogleCloudDatalabelingV1beta1TextEntityExtractionConfig

@typing.type_check_only
class GoogleCloudDatalabelingV1beta1LabelVideoClassificationOperationMetadata(
    typing_extensions.TypedDict, total=False
):
    basicConfig: GoogleCloudDatalabelingV1beta1HumanAnnotationConfig

@typing.type_check_only
class GoogleCloudDatalabelingV1beta1LabelVideoEventOperationMetadata(
    typing_extensions.TypedDict, total=False
):
    basicConfig: GoogleCloudDatalabelingV1beta1HumanAnnotationConfig

@typing.type_check_only
class GoogleCloudDatalabelingV1beta1LabelVideoObjectDetectionOperationMetadata(
    typing_extensions.TypedDict, total=False
):
    basicConfig: GoogleCloudDatalabelingV1beta1HumanAnnotationConfig

@typing.type_check_only
class GoogleCloudDatalabelingV1beta1LabelVideoObjectTrackingOperationMetadata(
    typing_extensions.TypedDict, total=False
):
    basicConfig: GoogleCloudDatalabelingV1beta1HumanAnnotationConfig

@typing.type_check_only
class GoogleCloudDatalabelingV1beta1LabelVideoRequest(
    typing_extensions.TypedDict, total=False
):
    basicConfig: GoogleCloudDatalabelingV1beta1HumanAnnotationConfig
    eventConfig: GoogleCloudDatalabelingV1beta1EventConfig
    feature: typing_extensions.Literal[
        "FEATURE_UNSPECIFIED",
        "CLASSIFICATION",
        "OBJECT_DETECTION",
        "OBJECT_TRACKING",
        "EVENT",
    ]
    objectDetectionConfig: GoogleCloudDatalabelingV1beta1ObjectDetectionConfig
    objectTrackingConfig: GoogleCloudDatalabelingV1beta1ObjectTrackingConfig
    videoClassificationConfig: GoogleCloudDatalabelingV1beta1VideoClassificationConfig

@typing.type_check_only
class GoogleCloudDatalabelingV1beta1ListAnnotatedDatasetsResponse(
    typing_extensions.TypedDict, total=False
):
    annotatedDatasets: _list[GoogleCloudDatalabelingV1beta1AnnotatedDataset]
    nextPageToken: str

@typing.type_check_only
class GoogleCloudDatalabelingV1beta1ListAnnotationSpecSetsResponse(
    typing_extensions.TypedDict, total=False
):
    annotationSpecSets: _list[GoogleCloudDatalabelingV1beta1AnnotationSpecSet]
    nextPageToken: str

@typing.type_check_only
class GoogleCloudDatalabelingV1beta1ListDataItemsResponse(
    typing_extensions.TypedDict, total=False
):
    dataItems: _list[GoogleCloudDatalabelingV1beta1DataItem]
    nextPageToken: str

@typing.type_check_only
class GoogleCloudDatalabelingV1beta1ListDatasetsResponse(
    typing_extensions.TypedDict, total=False
):
    datasets: _list[GoogleCloudDatalabelingV1beta1Dataset]
    nextPageToken: str

@typing.type_check_only
class GoogleCloudDatalabelingV1beta1ListEvaluationJobsResponse(
    typing_extensions.TypedDict, total=False
):
    evaluationJobs: _list[GoogleCloudDatalabelingV1beta1EvaluationJob]
    nextPageToken: str

@typing.type_check_only
class GoogleCloudDatalabelingV1beta1ListExamplesResponse(
    typing_extensions.TypedDict, total=False
):
    examples: _list[GoogleCloudDatalabelingV1beta1Example]
    nextPageToken: str

@typing.type_check_only
class GoogleCloudDatalabelingV1beta1ListFeedbackMessagesResponse(
    typing_extensions.TypedDict, total=False
):
    feedbackMessages: _list[GoogleCloudDatalabelingV1beta1FeedbackMessage]
    nextPageToken: str

@typing.type_check_only
class GoogleCloudDatalabelingV1beta1ListFeedbackThreadsResponse(
    typing_extensions.TypedDict, total=False
):
    feedbackThreads: _list[GoogleCloudDatalabelingV1beta1FeedbackThread]
    nextPageToken: str

@typing.type_check_only
class GoogleCloudDatalabelingV1beta1ListInstructionsResponse(
    typing_extensions.TypedDict, total=False
):
    instructions: _list[GoogleCloudDatalabelingV1beta1Instruction]
    nextPageToken: str

@typing.type_check_only
class GoogleCloudDatalabelingV1beta1NormalizedBoundingPoly(
    typing_extensions.TypedDict, total=False
):
    normalizedVertices: _list[GoogleCloudDatalabelingV1beta1NormalizedVertex]

@typing.type_check_only
class GoogleCloudDatalabelingV1beta1NormalizedPolyline(
    typing_extensions.TypedDict, total=False
):
    normalizedVertices: _list[GoogleCloudDatalabelingV1beta1NormalizedVertex]

@typing.type_check_only
class GoogleCloudDatalabelingV1beta1NormalizedVertex(
    typing_extensions.TypedDict, total=False
):
    x: float
    y: float

@typing.type_check_only
class GoogleCloudDatalabelingV1beta1ObjectDetectionConfig(
    typing_extensions.TypedDict, total=False
):
    annotationSpecSet: str
    extractionFrameRate: float

@typing.type_check_only
class GoogleCloudDatalabelingV1beta1ObjectDetectionMetrics(
    typing_extensions.TypedDict, total=False
):
    prCurve: GoogleCloudDatalabelingV1beta1PrCurve

@typing.type_check_only
class GoogleCloudDatalabelingV1beta1ObjectTrackingConfig(
    typing_extensions.TypedDict, total=False
):
    annotationSpecSet: str
    clipLength: int
    overlapLength: int

@typing.type_check_only
class GoogleCloudDatalabelingV1beta1ObjectTrackingFrame(
    typing_extensions.TypedDict, total=False
):
    boundingPoly: GoogleCloudDatalabelingV1beta1BoundingPoly
    normalizedBoundingPoly: GoogleCloudDatalabelingV1beta1NormalizedBoundingPoly
    timeOffset: str

@typing.type_check_only
class GoogleCloudDatalabelingV1beta1OperatorFeedbackMetadata(
    typing_extensions.TypedDict, total=False
): ...

@typing.type_check_only
class GoogleCloudDatalabelingV1beta1OperatorMetadata(
    typing_extensions.TypedDict, total=False
):
    comments: _list[str]
    labelVotes: int
    score: float
    totalVotes: int

@typing.type_check_only
class GoogleCloudDatalabelingV1beta1OutputConfig(
    typing_extensions.TypedDict, total=False
):
    gcsDestination: GoogleCloudDatalabelingV1beta1GcsDestination
    gcsFolderDestination: GoogleCloudDatalabelingV1beta1GcsFolderDestination

@typing.type_check_only
class GoogleCloudDatalabelingV1beta1PauseEvaluationJobRequest(
    typing_extensions.TypedDict, total=False
): ...

@typing.type_check_only
class GoogleCloudDatalabelingV1beta1PdfInstruction(
    typing_extensions.TypedDict, total=False
):
    gcsFileUri: str

@typing.type_check_only
class GoogleCloudDatalabelingV1beta1Polyline(typing_extensions.TypedDict, total=False):
    vertices: _list[GoogleCloudDatalabelingV1beta1Vertex]

@typing.type_check_only
class GoogleCloudDatalabelingV1beta1PolylineConfig(
    typing_extensions.TypedDict, total=False
):
    annotationSpecSet: str
    instructionMessage: str

@typing.type_check_only
class GoogleCloudDatalabelingV1beta1PrCurve(typing_extensions.TypedDict, total=False):
    annotationSpec: GoogleCloudDatalabelingV1beta1AnnotationSpec
    areaUnderCurve: float
    confidenceMetricsEntries: _list[
        GoogleCloudDatalabelingV1beta1ConfidenceMetricsEntry
    ]
    meanAveragePrecision: float

@typing.type_check_only
class GoogleCloudDatalabelingV1beta1RequesterFeedbackMetadata(
    typing_extensions.TypedDict, total=False
): ...

@typing.type_check_only
class GoogleCloudDatalabelingV1beta1ResumeEvaluationJobRequest(
    typing_extensions.TypedDict, total=False
): ...

@typing.type_check_only
class GoogleCloudDatalabelingV1beta1Row(typing_extensions.TypedDict, total=False):
    annotationSpec: GoogleCloudDatalabelingV1beta1AnnotationSpec
    entries: _list[GoogleCloudDatalabelingV1beta1ConfusionMatrixEntry]

@typing.type_check_only
class GoogleCloudDatalabelingV1beta1SearchEvaluationsResponse(
    typing_extensions.TypedDict, total=False
):
    evaluations: _list[GoogleCloudDatalabelingV1beta1Evaluation]
    nextPageToken: str

@typing.type_check_only
class GoogleCloudDatalabelingV1beta1SearchExampleComparisonsRequest(
    typing_extensions.TypedDict, total=False
):
    pageSize: int
    pageToken: str

@typing.type_check_only
class GoogleCloudDatalabelingV1beta1SearchExampleComparisonsResponse(
    typing_extensions.TypedDict, total=False
):
    exampleComparisons: _list[GoogleCloudDatalabelingV1beta1ExampleComparison]
    nextPageToken: str

@typing.type_check_only
class GoogleCloudDatalabelingV1beta1SegmentationConfig(
    typing_extensions.TypedDict, total=False
):
    annotationSpecSet: str
    instructionMessage: str

@typing.type_check_only
class GoogleCloudDatalabelingV1beta1SentimentConfig(
    typing_extensions.TypedDict, total=False
):
    enableLabelSentimentSelection: bool

@typing.type_check_only
class GoogleCloudDatalabelingV1beta1SequentialSegment(
    typing_extensions.TypedDict, total=False
):
    end: int
    start: int

@typing.type_check_only
class GoogleCloudDatalabelingV1beta1TextClassificationAnnotation(
    typing_extensions.TypedDict, total=False
):
    annotationSpec: GoogleCloudDatalabelingV1beta1AnnotationSpec

@typing.type_check_only
class GoogleCloudDatalabelingV1beta1TextClassificationConfig(
    typing_extensions.TypedDict, total=False
):
    allowMultiLabel: bool
    annotationSpecSet: str
    sentimentConfig: GoogleCloudDatalabelingV1beta1SentimentConfig

@typing.type_check_only
class GoogleCloudDatalabelingV1beta1TextEntityExtractionAnnotation(
    typing_extensions.TypedDict, total=False
):
    annotationSpec: GoogleCloudDatalabelingV1beta1AnnotationSpec
    sequentialSegment: GoogleCloudDatalabelingV1beta1SequentialSegment

@typing.type_check_only
class GoogleCloudDatalabelingV1beta1TextEntityExtractionConfig(
    typing_extensions.TypedDict, total=False
):
    annotationSpecSet: str

@typing.type_check_only
class GoogleCloudDatalabelingV1beta1TextMetadata(
    typing_extensions.TypedDict, total=False
):
    languageCode: str

@typing.type_check_only
class GoogleCloudDatalabelingV1beta1TextPayload(
    typing_extensions.TypedDict, total=False
):
    textContent: str

@typing.type_check_only
class GoogleCloudDatalabelingV1beta1TimeSegment(
    typing_extensions.TypedDict, total=False
):
    endTimeOffset: str
    startTimeOffset: str

@typing.type_check_only
class GoogleCloudDatalabelingV1beta1Vertex(typing_extensions.TypedDict, total=False):
    x: int
    y: int

@typing.type_check_only
class GoogleCloudDatalabelingV1beta1VideoClassificationAnnotation(
    typing_extensions.TypedDict, total=False
):
    annotationSpec: GoogleCloudDatalabelingV1beta1AnnotationSpec
    timeSegment: GoogleCloudDatalabelingV1beta1TimeSegment

@typing.type_check_only
class GoogleCloudDatalabelingV1beta1VideoClassificationConfig(
    typing_extensions.TypedDict, total=False
):
    annotationSpecSetConfigs: _list[
        GoogleCloudDatalabelingV1beta1AnnotationSpecSetConfig
    ]
    applyShotDetection: bool

@typing.type_check_only
class GoogleCloudDatalabelingV1beta1VideoEventAnnotation(
    typing_extensions.TypedDict, total=False
):
    annotationSpec: GoogleCloudDatalabelingV1beta1AnnotationSpec
    timeSegment: GoogleCloudDatalabelingV1beta1TimeSegment

@typing.type_check_only
class GoogleCloudDatalabelingV1beta1VideoObjectTrackingAnnotation(
    typing_extensions.TypedDict, total=False
):
    annotationSpec: GoogleCloudDatalabelingV1beta1AnnotationSpec
    objectTrackingFrames: _list[GoogleCloudDatalabelingV1beta1ObjectTrackingFrame]
    timeSegment: GoogleCloudDatalabelingV1beta1TimeSegment

@typing.type_check_only
class GoogleCloudDatalabelingV1beta1VideoPayload(
    typing_extensions.TypedDict, total=False
):
    frameRate: float
    mimeType: str
    signedUri: str
    videoThumbnails: _list[GoogleCloudDatalabelingV1beta1VideoThumbnail]
    videoUri: str

@typing.type_check_only
class GoogleCloudDatalabelingV1beta1VideoThumbnail(
    typing_extensions.TypedDict, total=False
):
    thumbnail: str
    timeOffset: str

@typing.type_check_only
class GoogleCloudDatalabelingV1p1alpha1CreateInstructionMetadata(
    typing_extensions.TypedDict, total=False
):
    createTime: str
    instruction: str
    partialFailures: _list[GoogleRpcStatus]

@typing.type_check_only
class GoogleCloudDatalabelingV1p1alpha1ExportDataOperationMetadata(
    typing_extensions.TypedDict, total=False
):
    annotatedDataset: str
    createTime: str
    dataset: str
    partialFailures: _list[GoogleRpcStatus]

@typing.type_check_only
class GoogleCloudDatalabelingV1p1alpha1ExportDataOperationResponse(
    typing_extensions.TypedDict, total=False
):
    annotatedDataset: str
    dataset: str
    exportCount: int
    labelStats: GoogleCloudDatalabelingV1p1alpha1LabelStats
    outputConfig: GoogleCloudDatalabelingV1p1alpha1OutputConfig
    totalCount: int

@typing.type_check_only
class GoogleCloudDatalabelingV1p1alpha1GcsDestination(
    typing_extensions.TypedDict, total=False
):
    mimeType: str
    outputUri: str

@typing.type_check_only
class GoogleCloudDatalabelingV1p1alpha1GcsFolderDestination(
    typing_extensions.TypedDict, total=False
):
    outputFolderUri: str

@typing.type_check_only
class GoogleCloudDatalabelingV1p1alpha1GenerateAnalysisReportOperationMetadata(
    typing_extensions.TypedDict, total=False
):
    createTime: str
    dataset: str

@typing.type_check_only
class GoogleCloudDatalabelingV1p1alpha1HumanAnnotationConfig(
    typing_extensions.TypedDict, total=False
):
    annotatedDatasetDescription: str
    annotatedDatasetDisplayName: str
    contributorEmails: _list[str]
    instruction: str
    labelGroup: str
    languageCode: str
    questionDuration: str
    replicaCount: int
    userEmailAddress: str

@typing.type_check_only
class GoogleCloudDatalabelingV1p1alpha1ImportDataOperationMetadata(
    typing_extensions.TypedDict, total=False
):
    createTime: str
    dataset: str
    partialFailures: _list[GoogleRpcStatus]

@typing.type_check_only
class GoogleCloudDatalabelingV1p1alpha1ImportDataOperationResponse(
    typing_extensions.TypedDict, total=False
):
    dataset: str
    importCount: int
    totalCount: int

@typing.type_check_only
class GoogleCloudDatalabelingV1p1alpha1LabelImageBoundingBoxOperationMetadata(
    typing_extensions.TypedDict, total=False
):
    basicConfig: GoogleCloudDatalabelingV1p1alpha1HumanAnnotationConfig

@typing.type_check_only
class GoogleCloudDatalabelingV1p1alpha1LabelImageBoundingPolyOperationMetadata(
    typing_extensions.TypedDict, total=False
):
    basicConfig: GoogleCloudDatalabelingV1p1alpha1HumanAnnotationConfig

@typing.type_check_only
class GoogleCloudDatalabelingV1p1alpha1LabelImageClassificationOperationMetadata(
    typing_extensions.TypedDict, total=False
):
    basicConfig: GoogleCloudDatalabelingV1p1alpha1HumanAnnotationConfig

@typing.type_check_only
class GoogleCloudDatalabelingV1p1alpha1LabelImageOrientedBoundingBoxOperationMetadata(
    typing_extensions.TypedDict, total=False
):
    basicConfig: GoogleCloudDatalabelingV1p1alpha1HumanAnnotationConfig

@typing.type_check_only
class GoogleCloudDatalabelingV1p1alpha1LabelImagePolylineOperationMetadata(
    typing_extensions.TypedDict, total=False
):
    basicConfig: GoogleCloudDatalabelingV1p1alpha1HumanAnnotationConfig

@typing.type_check_only
class GoogleCloudDatalabelingV1p1alpha1LabelImageSegmentationOperationMetadata(
    typing_extensions.TypedDict, total=False
):
    basicConfig: GoogleCloudDatalabelingV1p1alpha1HumanAnnotationConfig

@typing.type_check_only
class GoogleCloudDatalabelingV1p1alpha1LabelOperationMetadata(
    typing_extensions.TypedDict, total=False
):
    annotatedDataset: str
    createTime: str
    dataset: str
    imageBoundingBoxDetails: GoogleCloudDatalabelingV1p1alpha1LabelImageBoundingBoxOperationMetadata
    imageBoundingPolyDetails: GoogleCloudDatalabelingV1p1alpha1LabelImageBoundingPolyOperationMetadata
    imageClassificationDetails: GoogleCloudDatalabelingV1p1alpha1LabelImageClassificationOperationMetadata
    imageOrientedBoundingBoxDetails: GoogleCloudDatalabelingV1p1alpha1LabelImageOrientedBoundingBoxOperationMetadata
    imagePolylineDetails: GoogleCloudDatalabelingV1p1alpha1LabelImagePolylineOperationMetadata
    imageSegmentationDetails: GoogleCloudDatalabelingV1p1alpha1LabelImageSegmentationOperationMetadata
    partialFailures: _list[GoogleRpcStatus]
    progressPercent: int
    textClassificationDetails: GoogleCloudDatalabelingV1p1alpha1LabelTextClassificationOperationMetadata
    textEntityExtractionDetails: GoogleCloudDatalabelingV1p1alpha1LabelTextEntityExtractionOperationMetadata
    videoClassificationDetails: GoogleCloudDatalabelingV1p1alpha1LabelVideoClassificationOperationMetadata
    videoEventDetails: GoogleCloudDatalabelingV1p1alpha1LabelVideoEventOperationMetadata
    videoObjectDetectionDetails: GoogleCloudDatalabelingV1p1alpha1LabelVideoObjectDetectionOperationMetadata
    videoObjectTrackingDetails: GoogleCloudDatalabelingV1p1alpha1LabelVideoObjectTrackingOperationMetadata

@typing.type_check_only
class GoogleCloudDatalabelingV1p1alpha1LabelStats(
    typing_extensions.TypedDict, total=False
):
    exampleCount: dict[str, typing.Any]

@typing.type_check_only
class GoogleCloudDatalabelingV1p1alpha1LabelTextClassificationOperationMetadata(
    typing_extensions.TypedDict, total=False
):
    basicConfig: GoogleCloudDatalabelingV1p1alpha1HumanAnnotationConfig

@typing.type_check_only
class GoogleCloudDatalabelingV1p1alpha1LabelTextEntityExtractionOperationMetadata(
    typing_extensions.TypedDict, total=False
):
    basicConfig: GoogleCloudDatalabelingV1p1alpha1HumanAnnotationConfig

@typing.type_check_only
class GoogleCloudDatalabelingV1p1alpha1LabelVideoClassificationOperationMetadata(
    typing_extensions.TypedDict, total=False
):
    basicConfig: GoogleCloudDatalabelingV1p1alpha1HumanAnnotationConfig

@typing.type_check_only
class GoogleCloudDatalabelingV1p1alpha1LabelVideoEventOperationMetadata(
    typing_extensions.TypedDict, total=False
):
    basicConfig: GoogleCloudDatalabelingV1p1alpha1HumanAnnotationConfig

@typing.type_check_only
class GoogleCloudDatalabelingV1p1alpha1LabelVideoObjectDetectionOperationMetadata(
    typing_extensions.TypedDict, total=False
):
    basicConfig: GoogleCloudDatalabelingV1p1alpha1HumanAnnotationConfig

@typing.type_check_only
class GoogleCloudDatalabelingV1p1alpha1LabelVideoObjectTrackingOperationMetadata(
    typing_extensions.TypedDict, total=False
):
    basicConfig: GoogleCloudDatalabelingV1p1alpha1HumanAnnotationConfig

@typing.type_check_only
class GoogleCloudDatalabelingV1p1alpha1OutputConfig(
    typing_extensions.TypedDict, total=False
):
    gcsDestination: GoogleCloudDatalabelingV1p1alpha1GcsDestination
    gcsFolderDestination: GoogleCloudDatalabelingV1p1alpha1GcsFolderDestination

@typing.type_check_only
class GoogleCloudDatalabelingV1p2alpha1CreateInstructionMetadata(
    typing_extensions.TypedDict, total=False
):
    createTime: str
    instruction: str
    partialFailures: _list[GoogleRpcStatus]

@typing.type_check_only
class GoogleCloudDatalabelingV1p2alpha1ExportDataOperationMetadata(
    typing_extensions.TypedDict, total=False
):
    annotatedDataset: str
    createTime: str
    dataset: str
    partialFailures: _list[GoogleRpcStatus]

@typing.type_check_only
class GoogleCloudDatalabelingV1p2alpha1ExportDataOperationResponse(
    typing_extensions.TypedDict, total=False
):
    annotatedDataset: str
    dataset: str
    exportCount: int
    labelStats: GoogleCloudDatalabelingV1p2alpha1LabelStats
    outputConfig: GoogleCloudDatalabelingV1p2alpha1OutputConfig
    totalCount: int

@typing.type_check_only
class GoogleCloudDatalabelingV1p2alpha1GcsDestination(
    typing_extensions.TypedDict, total=False
):
    mimeType: str
    outputUri: str

@typing.type_check_only
class GoogleCloudDatalabelingV1p2alpha1GcsFolderDestination(
    typing_extensions.TypedDict, total=False
):
    outputFolderUri: str

@typing.type_check_only
class GoogleCloudDatalabelingV1p2alpha1HumanAnnotationConfig(
    typing_extensions.TypedDict, total=False
):
    annotatedDatasetDescription: str
    annotatedDatasetDisplayName: str
    contributorEmails: _list[str]
    instruction: str
    labelGroup: str
    languageCode: str
    questionDuration: str
    replicaCount: int
    userEmailAddress: str

@typing.type_check_only
class GoogleCloudDatalabelingV1p2alpha1ImportDataOperationMetadata(
    typing_extensions.TypedDict, total=False
):
    createTime: str
    dataset: str
    partialFailures: _list[GoogleRpcStatus]

@typing.type_check_only
class GoogleCloudDatalabelingV1p2alpha1ImportDataOperationResponse(
    typing_extensions.TypedDict, total=False
):
    dataset: str
    importCount: int
    totalCount: int

@typing.type_check_only
class GoogleCloudDatalabelingV1p2alpha1LabelImageBoundingBoxOperationMetadata(
    typing_extensions.TypedDict, total=False
):
    basicConfig: GoogleCloudDatalabelingV1p2alpha1HumanAnnotationConfig

@typing.type_check_only
class GoogleCloudDatalabelingV1p2alpha1LabelImageBoundingPolyOperationMetadata(
    typing_extensions.TypedDict, total=False
):
    basicConfig: GoogleCloudDatalabelingV1p2alpha1HumanAnnotationConfig

@typing.type_check_only
class GoogleCloudDatalabelingV1p2alpha1LabelImageClassificationOperationMetadata(
    typing_extensions.TypedDict, total=False
):
    basicConfig: GoogleCloudDatalabelingV1p2alpha1HumanAnnotationConfig

@typing.type_check_only
class GoogleCloudDatalabelingV1p2alpha1LabelImageOrientedBoundingBoxOperationMetadata(
    typing_extensions.TypedDict, total=False
):
    basicConfig: GoogleCloudDatalabelingV1p2alpha1HumanAnnotationConfig

@typing.type_check_only
class GoogleCloudDatalabelingV1p2alpha1LabelImagePolylineOperationMetadata(
    typing_extensions.TypedDict, total=False
):
    basicConfig: GoogleCloudDatalabelingV1p2alpha1HumanAnnotationConfig

@typing.type_check_only
class GoogleCloudDatalabelingV1p2alpha1LabelImageSegmentationOperationMetadata(
    typing_extensions.TypedDict, total=False
):
    basicConfig: GoogleCloudDatalabelingV1p2alpha1HumanAnnotationConfig

@typing.type_check_only
class GoogleCloudDatalabelingV1p2alpha1LabelOperationMetadata(
    typing_extensions.TypedDict, total=False
):
    annotatedDataset: str
    createTime: str
    dataset: str
    imageBoundingBoxDetails: GoogleCloudDatalabelingV1p2alpha1LabelImageBoundingBoxOperationMetadata
    imageBoundingPolyDetails: GoogleCloudDatalabelingV1p2alpha1LabelImageBoundingPolyOperationMetadata
    imageClassificationDetails: GoogleCloudDatalabelingV1p2alpha1LabelImageClassificationOperationMetadata
    imageOrientedBoundingBoxDetails: GoogleCloudDatalabelingV1p2alpha1LabelImageOrientedBoundingBoxOperationMetadata
    imagePolylineDetails: GoogleCloudDatalabelingV1p2alpha1LabelImagePolylineOperationMetadata
    imageSegmentationDetails: GoogleCloudDatalabelingV1p2alpha1LabelImageSegmentationOperationMetadata
    partialFailures: _list[GoogleRpcStatus]
    progressPercent: int
    textClassificationDetails: GoogleCloudDatalabelingV1p2alpha1LabelTextClassificationOperationMetadata
    textEntityExtractionDetails: GoogleCloudDatalabelingV1p2alpha1LabelTextEntityExtractionOperationMetadata
    videoClassificationDetails: GoogleCloudDatalabelingV1p2alpha1LabelVideoClassificationOperationMetadata
    videoEventDetails: GoogleCloudDatalabelingV1p2alpha1LabelVideoEventOperationMetadata
    videoObjectDetectionDetails: GoogleCloudDatalabelingV1p2alpha1LabelVideoObjectDetectionOperationMetadata
    videoObjectTrackingDetails: GoogleCloudDatalabelingV1p2alpha1LabelVideoObjectTrackingOperationMetadata

@typing.type_check_only
class GoogleCloudDatalabelingV1p2alpha1LabelStats(
    typing_extensions.TypedDict, total=False
):
    exampleCount: dict[str, typing.Any]

@typing.type_check_only
class GoogleCloudDatalabelingV1p2alpha1LabelTextClassificationOperationMetadata(
    typing_extensions.TypedDict, total=False
):
    basicConfig: GoogleCloudDatalabelingV1p2alpha1HumanAnnotationConfig

@typing.type_check_only
class GoogleCloudDatalabelingV1p2alpha1LabelTextEntityExtractionOperationMetadata(
    typing_extensions.TypedDict, total=False
):
    basicConfig: GoogleCloudDatalabelingV1p2alpha1HumanAnnotationConfig

@typing.type_check_only
class GoogleCloudDatalabelingV1p2alpha1LabelVideoClassificationOperationMetadata(
    typing_extensions.TypedDict, total=False
):
    basicConfig: GoogleCloudDatalabelingV1p2alpha1HumanAnnotationConfig

@typing.type_check_only
class GoogleCloudDatalabelingV1p2alpha1LabelVideoEventOperationMetadata(
    typing_extensions.TypedDict, total=False
):
    basicConfig: GoogleCloudDatalabelingV1p2alpha1HumanAnnotationConfig

@typing.type_check_only
class GoogleCloudDatalabelingV1p2alpha1LabelVideoObjectDetectionOperationMetadata(
    typing_extensions.TypedDict, total=False
):
    basicConfig: GoogleCloudDatalabelingV1p2alpha1HumanAnnotationConfig

@typing.type_check_only
class GoogleCloudDatalabelingV1p2alpha1LabelVideoObjectTrackingOperationMetadata(
    typing_extensions.TypedDict, total=False
):
    basicConfig: GoogleCloudDatalabelingV1p2alpha1HumanAnnotationConfig

@typing.type_check_only
class GoogleCloudDatalabelingV1p2alpha1OutputConfig(
    typing_extensions.TypedDict, total=False
):
    gcsDestination: GoogleCloudDatalabelingV1p2alpha1GcsDestination
    gcsFolderDestination: GoogleCloudDatalabelingV1p2alpha1GcsFolderDestination

@typing.type_check_only
class GoogleLongrunningListOperationsResponse(typing_extensions.TypedDict, total=False):
    nextPageToken: str
    operations: _list[GoogleLongrunningOperation]

@typing.type_check_only
class GoogleLongrunningOperation(typing_extensions.TypedDict, total=False):
    done: bool
    error: GoogleRpcStatus
    metadata: dict[str, typing.Any]
    name: str
    response: dict[str, typing.Any]

@typing.type_check_only
class GoogleProtobufEmpty(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class GoogleRpcStatus(typing_extensions.TypedDict, total=False):
    code: int
    details: _list[dict[str, typing.Any]]
    message: str



import typing

import typing_extensions

_list = list

@typing.type_check_only
class AuditConfig(typing_extensions.TypedDict, total=False):
    auditLogConfigs: _list[AuditLogConfig]
    service: str

@typing.type_check_only
class AuditLogConfig(typing_extensions.TypedDict, total=False):
    exemptedMembers: _list[str]
    logType: typing_extensions.Literal[
        "LOG_TYPE_UNSPECIFIED", "ADMIN_READ", "DATA_WRITE", "DATA_READ"
    ]

@typing.type_check_only
class Binding(typing_extensions.TypedDict, total=False):
    condition: Expr
    members: _list[str]
    role: str

@typing.type_check_only
class CloudSqlCredential(typing_extensions.TypedDict, total=False):
    password: str
    username: str

@typing.type_check_only
class CloudSqlProperties(typing_extensions.TypedDict, total=False):
    credential: CloudSqlCredential
    database: str
    instanceId: str
    serviceAccountId: str
    type: typing_extensions.Literal["DATABASE_TYPE_UNSPECIFIED", "POSTGRES", "MYSQL"]

@typing.type_check_only
class Connection(typing_extensions.TypedDict, total=False):
    cloudSql: CloudSqlProperties
    creationTime: str
    description: str
    friendlyName: str
    hasCredential: bool
    lastModifiedTime: str
    name: str

@typing.type_check_only
class ConnectionCredential(typing_extensions.TypedDict, total=False):
    cloudSql: CloudSqlCredential

@typing.type_check_only
class Empty(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class Expr(typing_extensions.TypedDict, total=False):
    description: str
    expression: str
    location: str
    title: str

@typing.type_check_only
class GetIamPolicyRequest(typing_extensions.TypedDict, total=False):
    options: GetPolicyOptions

@typing.type_check_only
class GetPolicyOptions(typing_extensions.TypedDict, total=False):
    requestedPolicyVersion: int

@typing.type_check_only
class ListConnectionsResponse(typing_extensions.TypedDict, total=False):
    connections: _list[Connection]
    nextPageToken: str

@typing.type_check_only
class Policy(typing_extensions.TypedDict, total=False):
    auditConfigs: _list[AuditConfig]
    bindings: _list[Binding]
    etag: str
    version: int

@typing.type_check_only
class SetIamPolicyRequest(typing_extensions.TypedDict, total=False):
    policy: Policy
    updateMask: str

@typing.type_check_only
class TestIamPermissionsRequest(typing_extensions.TypedDict, total=False):
    permissions: _list[str]

@typing.type_check_only
class TestIamPermissionsResponse(typing_extensions.TypedDict, total=False):
    permissions: _list[str]



import typing

import typing_extensions

_list = list

@typing.type_check_only
class ChannelGrouping(typing_extensions.TypedDict, total=False):
    fallbackName: str
    name: str
    rules: _list[Rule]

@typing.type_check_only
class DisjunctiveMatchStatement(typing_extensions.TypedDict, total=False):
    eventFilters: _list[EventFilter]

@typing.type_check_only
class EventFilter(typing_extensions.TypedDict, total=False):
    dimensionFilter: PathQueryOptionsFilter

@typing.type_check_only
class FilterPair(typing_extensions.TypedDict, total=False):
    type: typing_extensions.Literal[
        "FILTER_UNKNOWN",
        "FILTER_DATE",
        "FILTER_DAY_OF_WEEK",
        "FILTER_WEEK",
        "FILTER_MONTH",
        "FILTER_YEAR",
        "FILTER_TIME_OF_DAY",
        "FILTER_CONVERSION_DELAY",
        "FILTER_CREATIVE_ID",
        "FILTER_CREATIVE_SIZE",
        "FILTER_CREATIVE_TYPE",
        "FILTER_EXCHANGE_ID",
        "FILTER_AD_POSITION",
        "FILTER_PUBLIC_INVENTORY",
        "FILTER_INVENTORY_SOURCE",
        "FILTER_CITY",
        "FILTER_REGION",
        "FILTER_DMA",
        "FILTER_COUNTRY",
        "FILTER_SITE_ID",
        "FILTER_CHANNEL_ID",
        "FILTER_PARTNER",
        "FILTER_ADVERTISER",
        "FILTER_INSERTION_ORDER",
        "FILTER_LINE_ITEM",
        "FILTER_PARTNER_CURRENCY",
        "FILTER_ADVERTISER_CURRENCY",
        "FILTER_ADVERTISER_TIMEZONE",
        "FILTER_LINE_ITEM_TYPE",
        "FILTER_USER_LIST",
        "FILTER_USER_LIST_FIRST_PARTY",
        "FILTER_USER_LIST_THIRD_PARTY",
        "FILTER_TARGETED_USER_LIST",
        "FILTER_DATA_PROVIDER",
        "FILTER_ORDER_ID",
        "FILTER_VIDEO_PLAYER_SIZE",
        "FILTER_VIDEO_DURATION_SECONDS",
        "FILTER_KEYWORD",
        "FILTER_PAGE_CATEGORY",
        "FILTER_CAMPAIGN_DAILY_FREQUENCY",
        "FILTER_LINE_ITEM_DAILY_FREQUENCY",
        "FILTER_LINE_ITEM_LIFETIME_FREQUENCY",
        "FILTER_OS",
        "FILTER_BROWSER",
        "FILTER_CARRIER",
        "FILTER_SITE_LANGUAGE",
        "FILTER_INVENTORY_FORMAT",
        "FILTER_ZIP_CODE",
        "FILTER_VIDEO_RATING_TIER",
        "FILTER_VIDEO_FORMAT_SUPPORT",
        "FILTER_VIDEO_SKIPPABLE_SUPPORT",
        "FILTER_VIDEO_CREATIVE_DURATION",
        "FILTER_PAGE_LAYOUT",
        "FILTER_VIDEO_AD_POSITION_IN_STREAM",
        "FILTER_AGE",
        "FILTER_GENDER",
        "FILTER_QUARTER",
        "FILTER_TRUEVIEW_CONVERSION_TYPE",
        "FILTER_MOBILE_GEO",
        "FILTER_MRAID_SUPPORT",
        "FILTER_ACTIVE_VIEW_EXPECTED_VIEWABILITY",
        "FILTER_VIDEO_CREATIVE_DURATION_SKIPPABLE",
        "FILTER_NIELSEN_COUNTRY_CODE",
        "FILTER_NIELSEN_DEVICE_ID",
        "FILTER_NIELSEN_GENDER",
        "FILTER_NIELSEN_AGE",
        "FILTER_INVENTORY_SOURCE_TYPE",
        "FILTER_CREATIVE_WIDTH",
        "FILTER_CREATIVE_HEIGHT",
        "FILTER_DFP_ORDER_ID",
        "FILTER_TRUEVIEW_AGE",
        "FILTER_TRUEVIEW_GENDER",
        "FILTER_TRUEVIEW_PARENTAL_STATUS",
        "FILTER_TRUEVIEW_REMARKETING_LIST",
        "FILTER_TRUEVIEW_INTEREST",
        "FILTER_TRUEVIEW_AD_GROUP_ID",
        "FILTER_TRUEVIEW_AD_GROUP_AD_ID",
        "FILTER_TRUEVIEW_IAR_LANGUAGE",
        "FILTER_TRUEVIEW_IAR_GENDER",
        "FILTER_TRUEVIEW_IAR_AGE",
        "FILTER_TRUEVIEW_IAR_CATEGORY",
        "FILTER_TRUEVIEW_IAR_COUNTRY",
        "FILTER_TRUEVIEW_IAR_CITY",
        "FILTER_TRUEVIEW_IAR_REGION",
        "FILTER_TRUEVIEW_IAR_ZIPCODE",
        "FILTER_TRUEVIEW_IAR_REMARKETING_LIST",
        "FILTER_TRUEVIEW_IAR_INTEREST",
        "FILTER_TRUEVIEW_IAR_PARENTAL_STATUS",
        "FILTER_TRUEVIEW_IAR_TIME_OF_DAY",
        "FILTER_TRUEVIEW_CUSTOM_AFFINITY",
        "FILTER_TRUEVIEW_CATEGORY",
        "FILTER_TRUEVIEW_KEYWORD",
        "FILTER_TRUEVIEW_PLACEMENT",
        "FILTER_TRUEVIEW_URL",
        "FILTER_TRUEVIEW_COUNTRY",
        "FILTER_TRUEVIEW_REGION",
        "FILTER_TRUEVIEW_CITY",
        "FILTER_TRUEVIEW_DMA",
        "FILTER_TRUEVIEW_ZIPCODE",
        "FILTER_NOT_SUPPORTED",
        "FILTER_MEDIA_PLAN",
        "FILTER_TRUEVIEW_IAR_YOUTUBE_CHANNEL",
        "FILTER_TRUEVIEW_IAR_YOUTUBE_VIDEO",
        "FILTER_SKIPPABLE_SUPPORT",
        "FILTER_COMPANION_CREATIVE_ID",
        "FILTER_BUDGET_SEGMENT_DESCRIPTION",
        "FILTER_FLOODLIGHT_ACTIVITY_ID",
        "FILTER_DEVICE_MODEL",
        "FILTER_DEVICE_MAKE",
        "FILTER_DEVICE_TYPE",
        "FILTER_CREATIVE_ATTRIBUTE",
        "FILTER_INVENTORY_COMMITMENT_TYPE",
        "FILTER_INVENTORY_RATE_TYPE",
        "FILTER_INVENTORY_DELIVERY_METHOD",
        "FILTER_INVENTORY_SOURCE_EXTERNAL_ID",
        "FILTER_AUTHORIZED_SELLER_STATE",
        "FILTER_VIDEO_DURATION_SECONDS_RANGE",
        "FILTER_PARTNER_NAME",
        "FILTER_PARTNER_STATUS",
        "FILTER_ADVERTISER_NAME",
        "FILTER_ADVERTISER_INTEGRATION_CODE",
        "FILTER_ADVERTISER_INTEGRATION_STATUS",
        "FILTER_CARRIER_NAME",
        "FILTER_CHANNEL_NAME",
        "FILTER_CITY_NAME",
        "FILTER_COMPANION_CREATIVE_NAME",
        "FILTER_USER_LIST_FIRST_PARTY_NAME",
        "FILTER_USER_LIST_THIRD_PARTY_NAME",
        "FILTER_NIELSEN_RESTATEMENT_DATE",
        "FILTER_NIELSEN_DATE_RANGE",
        "FILTER_INSERTION_ORDER_NAME",
        "FILTER_REGION_NAME",
        "FILTER_DMA_NAME",
        "FILTER_TRUEVIEW_IAR_REGION_NAME",
        "FILTER_TRUEVIEW_DMA_NAME",
        "FILTER_TRUEVIEW_REGION_NAME",
        "FILTER_ACTIVE_VIEW_CUSTOM_METRIC_ID",
        "FILTER_ACTIVE_VIEW_CUSTOM_METRIC_NAME",
        "FILTER_AD_TYPE",
        "FILTER_ALGORITHM",
        "FILTER_ALGORITHM_ID",
        "FILTER_AMP_PAGE_REQUEST",
        "FILTER_ANONYMOUS_INVENTORY_MODELING",
        "FILTER_APP_URL",
        "FILTER_APP_URL_EXCLUDED",
        "FILTER_ATTRIBUTED_USERLIST",
        "FILTER_ATTRIBUTED_USERLIST_COST",
        "FILTER_ATTRIBUTED_USERLIST_TYPE",
        "FILTER_ATTRIBUTION_MODEL",
        "FILTER_AUDIENCE_LIST",
        "FILTER_AUDIENCE_LIST_COST",
        "FILTER_AUDIENCE_LIST_TYPE",
        "FILTER_AUDIENCE_NAME",
        "FILTER_AUDIENCE_TYPE",
        "FILTER_BILLABLE_OUTCOME",
        "FILTER_BRAND_LIFT_TYPE",
        "FILTER_CHANNEL_TYPE",
        "FILTER_CM_PLACEMENT_ID",
        "FILTER_CONVERSION_SOURCE",
        "FILTER_CONVERSION_SOURCE_ID",
        "FILTER_COUNTRY_ID",
        "FILTER_CREATIVE",
        "FILTER_CREATIVE_ASSET",
        "FILTER_CREATIVE_INTEGRATION_CODE",
        "FILTER_CREATIVE_RENDERED_IN_AMP",
        "FILTER_CREATIVE_SOURCE",
        "FILTER_CREATIVE_STATUS",
        "FILTER_DATA_PROVIDER_NAME",
        "FILTER_DETAILED_DEMOGRAPHICS",
        "FILTER_DETAILED_DEMOGRAPHICS_ID",
        "FILTER_DEVICE",
        "FILTER_GAM_INSERTION_ORDER",
        "FILTER_GAM_LINE_ITEM",
        "FILTER_GAM_LINE_ITEM_ID",
        "FILTER_DIGITAL_CONTENT_LABEL",
        "FILTER_DOMAIN",
        "FILTER_ELIGIBLE_COOKIES_ON_FIRST_PARTY_AUDIENCE_LIST",
        "FILTER_ELIGIBLE_COOKIES_ON_THIRD_PARTY_AUDIENCE_LIST_AND_INTEREST",
        "FILTER_EXCHANGE",
        "FILTER_EXCHANGE_CODE",
        "FILTER_EXTENSION",
        "FILTER_EXTENSION_STATUS",
        "FILTER_EXTENSION_TYPE",
        "FILTER_FIRST_PARTY_AUDIENCE_LIST_COST",
        "FILTER_FIRST_PARTY_AUDIENCE_LIST_TYPE",
        "FILTER_FLOODLIGHT_ACTIVITY",
        "FILTER_FORMAT",
        "FILTER_GMAIL_AGE",
        "FILTER_GMAIL_CITY",
        "FILTER_GMAIL_COUNTRY",
        "FILTER_GMAIL_COUNTRY_NAME",
        "FILTER_GMAIL_DEVICE_TYPE",
        "FILTER_GMAIL_DEVICE_TYPE_NAME",
        "FILTER_GMAIL_GENDER",
        "FILTER_GMAIL_REGION",
        "FILTER_GMAIL_REMARKETING_LIST",
        "FILTER_HOUSEHOLD_INCOME",
        "FILTER_IMPRESSION_COUNTING_METHOD",
        "FILTER_YOUTUBE_PROGRAMMATIC_GUARANTEED_INSERTION_ORDER",
        "FILTER_INSERTION_ORDER_INTEGRATION_CODE",
        "FILTER_INSERTION_ORDER_STATUS",
        "FILTER_INTEREST",
        "FILTER_INVENTORY_SOURCE_GROUP",
        "FILTER_INVENTORY_SOURCE_GROUP_ID",
        "FILTER_INVENTORY_SOURCE_ID",
        "FILTER_INVENTORY_SOURCE_NAME",
        "FILTER_LIFE_EVENT",
        "FILTER_LIFE_EVENTS",
        "FILTER_LINE_ITEM_INTEGRATION_CODE",
        "FILTER_LINE_ITEM_NAME",
        "FILTER_LINE_ITEM_STATUS",
        "FILTER_MATCH_RATIO",
        "FILTER_MEASUREMENT_SOURCE",
        "FILTER_MEDIA_PLAN_NAME",
        "FILTER_PARENTAL_STATUS",
        "FILTER_PLACEMENT_ALL_YOUTUBE_CHANNELS",
        "FILTER_PLATFORM",
        "FILTER_PLAYBACK_METHOD",
        "FILTER_POSITION_IN_CONTENT",
        "FILTER_PUBLISHER_PROPERTY",
        "FILTER_PUBLISHER_PROPERTY_ID",
        "FILTER_PUBLISHER_PROPERTY_SECTION",
        "FILTER_PUBLISHER_PROPERTY_SECTION_ID",
        "FILTER_REFUND_REASON",
        "FILTER_REMARKETING_LIST",
        "FILTER_REWARDED",
        "FILTER_SENSITIVE_CATEGORY",
        "FILTER_SERVED_PIXEL_DENSITY",
        "FILTER_TARGETED_DATA_PROVIDERS",
        "FILTER_THIRD_PARTY_AUDIENCE_LIST_COST",
        "FILTER_THIRD_PARTY_AUDIENCE_LIST_TYPE",
        "FILTER_TRUEVIEW_AD",
        "FILTER_TRUEVIEW_AD_GROUP",
        "FILTER_TRUEVIEW_DETAILED_DEMOGRAPHICS",
        "FILTER_TRUEVIEW_DETAILED_DEMOGRAPHICS_ID",
        "FILTER_TRUEVIEW_HOUSEHOLD_INCOME",
        "FILTER_TRUEVIEW_IAR_COUNTRY_NAME",
        "FILTER_TRUEVIEW_REMARKETING_LIST_NAME",
        "FILTER_VARIANT_ID",
        "FILTER_VARIANT_NAME",
        "FILTER_VARIANT_VERSION",
        "FILTER_VERIFICATION_VIDEO_PLAYER_SIZE",
        "FILTER_VERIFICATION_VIDEO_POSITION",
        "FILTER_VIDEO_COMPANION_CREATIVE_SIZE",
        "FILTER_VIDEO_CONTINUOUS_PLAY",
        "FILTER_VIDEO_DURATION",
        "FILTER_YOUTUBE_ADAPTED_AUDIENCE_LIST",
        "FILTER_YOUTUBE_AD_VIDEO",
        "FILTER_YOUTUBE_AD_VIDEO_ID",
        "FILTER_YOUTUBE_CHANNEL",
        "FILTER_YOUTUBE_PROGRAMMATIC_GUARANTEED_ADVERTISER",
        "FILTER_YOUTUBE_PROGRAMMATIC_GUARANTEED_PARTNER",
        "FILTER_YOUTUBE_VIDEO",
        "FILTER_ZIP_POSTAL_CODE",
        "FILTER_PLACEMENT_NAME_ALL_YOUTUBE_CHANNELS",
        "FILTER_TRUEVIEW_PLACEMENT_ID",
        "FILTER_PATH_PATTERN_ID",
        "FILTER_PATH_EVENT_INDEX",
        "FILTER_EVENT_TYPE",
        "FILTER_CHANNEL_GROUPING",
        "FILTER_OM_SDK_AVAILABLE",
        "FILTER_DATA_SOURCE",
        "FILTER_CM360_PLACEMENT_ID",
        "FILTER_TRUEVIEW_CLICK_TYPE_NAME",
        "FILTER_TRUEVIEW_AD_TYPE_NAME",
        "FILTER_VIDEO_CONTENT_DURATION",
        "FILTER_MATCHED_GENRE_TARGET",
        "FILTER_VIDEO_CONTENT_LIVE_STREAM",
        "FILTER_BUDGET_SEGMENT_TYPE",
        "FILTER_BUDGET_SEGMENT_BUDGET",
        "FILTER_BUDGET_SEGMENT_START_DATE",
        "FILTER_BUDGET_SEGMENT_END_DATE",
        "FILTER_BUDGET_SEGMENT_PACING_PERCENTAGE",
        "FILTER_LINE_ITEM_BUDGET",
        "FILTER_LINE_ITEM_START_DATE",
        "FILTER_LINE_ITEM_END_DATE",
        "FILTER_INSERTION_ORDER_GOAL_TYPE",
        "FILTER_LINE_ITEM_PACING_PERCENTAGE",
        "FILTER_INSERTION_ORDER_GOAL_VALUE",
        "FILTER_OMID_CAPABLE",
        "FILTER_VENDOR_MEASUREMENT_MODE",
        "FILTER_IMPRESSION_LOSS_REJECTION_REASON",
        "FILTER_VERIFICATION_VIDEO_PLAYER_SIZE_START",
        "FILTER_VERIFICATION_VIDEO_PLAYER_SIZE_FIRST_QUARTILE",
        "FILTER_VERIFICATION_VIDEO_PLAYER_SIZE_MID_POINT",
        "FILTER_VERIFICATION_VIDEO_PLAYER_SIZE_THIRD_QUARTILE",
        "FILTER_VERIFICATION_VIDEO_PLAYER_SIZE_COMPLETE",
        "FILTER_VERIFICATION_VIDEO_RESIZED",
        "FILTER_VERIFICATION_AUDIBILITY_START",
        "FILTER_VERIFICATION_AUDIBILITY_COMPLETE",
        "FILTER_MEDIA_TYPE",
        "FILTER_AUDIO_FEED_TYPE_NAME",
        "FILTER_TRUEVIEW_TARGETING_EXPANSION",
        "FILTER_PUBLISHER_TRAFFIC_SOURCE",
    ]
    value: str

@typing.type_check_only
class ListQueriesResponse(typing_extensions.TypedDict, total=False):
    kind: str
    nextPageToken: str
    queries: _list[Query]

@typing.type_check_only
class ListReportsResponse(typing_extensions.TypedDict, total=False):
    kind: str
    nextPageToken: str
    reports: _list[Report]

@typing.type_check_only
class Options(typing_extensions.TypedDict, total=False):
    includeOnlyTargetedUserLists: bool
    pathQueryOptions: PathQueryOptions

@typing.type_check_only
class Parameters(typing_extensions.TypedDict, total=False):
    filters: _list[FilterPair]
    groupBys: _list[str]
    includeInviteData: bool
    metrics: _list[str]
    options: Options
    type: typing_extensions.Literal[
        "TYPE_GENERAL",
        "TYPE_AUDIENCE_PERFORMANCE",
        "TYPE_INVENTORY_AVAILABILITY",
        "TYPE_KEYWORD",
        "TYPE_PIXEL_LOAD",
        "TYPE_AUDIENCE_COMPOSITION",
        "TYPE_CROSS_PARTNER",
        "TYPE_PAGE_CATEGORY",
        "TYPE_THIRD_PARTY_DATA_PROVIDER",
        "TYPE_CROSS_PARTNER_THIRD_PARTY_DATA_PROVIDER",
        "TYPE_CLIENT_SAFE",
        "TYPE_ORDER_ID",
        "TYPE_FEE",
        "TYPE_CROSS_FEE",
        "TYPE_ACTIVE_GRP",
        "TYPE_YOUTUBE_VERTICAL",
        "TYPE_COMSCORE_VCE",
        "TYPE_TRUEVIEW",
        "TYPE_NIELSEN_AUDIENCE_PROFILE",
        "TYPE_NIELSEN_DAILY_REACH_BUILD",
        "TYPE_NIELSEN_SITE",
        "TYPE_REACH_AND_FREQUENCY",
        "TYPE_ESTIMATED_CONVERSION",
        "TYPE_VERIFICATION",
        "TYPE_TRUEVIEW_IAR",
        "TYPE_NIELSEN_ONLINE_GLOBAL_MARKET",
        "TYPE_PETRA_NIELSEN_AUDIENCE_PROFILE",
        "TYPE_PETRA_NIELSEN_DAILY_REACH_BUILD",
        "TYPE_PETRA_NIELSEN_ONLINE_GLOBAL_MARKET",
        "TYPE_NOT_SUPPORTED",
        "TYPE_REACH_AUDIENCE",
        "TYPE_LINEAR_TV_SEARCH_LIFT",
        "TYPE_PATH",
        "TYPE_PATH_ATTRIBUTION",
    ]

@typing.type_check_only
class PathFilter(typing_extensions.TypedDict, total=False):
    eventFilters: _list[EventFilter]
    pathMatchPosition: typing_extensions.Literal["ANY", "FIRST", "LAST"]

@typing.type_check_only
class PathQueryOptions(typing_extensions.TypedDict, total=False):
    channelGrouping: ChannelGrouping
    pathFilters: _list[PathFilter]

@typing.type_check_only
class PathQueryOptionsFilter(typing_extensions.TypedDict, total=False):
    filter: typing_extensions.Literal[
        "FILTER_UNKNOWN",
        "FILTER_DATE",
        "FILTER_DAY_OF_WEEK",
        "FILTER_WEEK",
        "FILTER_MONTH",
        "FILTER_YEAR",
        "FILTER_TIME_OF_DAY",
        "FILTER_CONVERSION_DELAY",
        "FILTER_CREATIVE_ID",
        "FILTER_CREATIVE_SIZE",
        "FILTER_CREATIVE_TYPE",
        "FILTER_EXCHANGE_ID",
        "FILTER_AD_POSITION",
        "FILTER_PUBLIC_INVENTORY",
        "FILTER_INVENTORY_SOURCE",
        "FILTER_CITY",
        "FILTER_REGION",
        "FILTER_DMA",
        "FILTER_COUNTRY",
        "FILTER_SITE_ID",
        "FILTER_CHANNEL_ID",
        "FILTER_PARTNER",
        "FILTER_ADVERTISER",
        "FILTER_INSERTION_ORDER",
        "FILTER_LINE_ITEM",
        "FILTER_PARTNER_CURRENCY",
        "FILTER_ADVERTISER_CURRENCY",
        "FILTER_ADVERTISER_TIMEZONE",
        "FILTER_LINE_ITEM_TYPE",
        "FILTER_USER_LIST",
        "FILTER_USER_LIST_FIRST_PARTY",
        "FILTER_USER_LIST_THIRD_PARTY",
        "FILTER_TARGETED_USER_LIST",
        "FILTER_DATA_PROVIDER",
        "FILTER_ORDER_ID",
        "FILTER_VIDEO_PLAYER_SIZE",
        "FILTER_VIDEO_DURATION_SECONDS",
        "FILTER_KEYWORD",
        "FILTER_PAGE_CATEGORY",
        "FILTER_CAMPAIGN_DAILY_FREQUENCY",
        "FILTER_LINE_ITEM_DAILY_FREQUENCY",
        "FILTER_LINE_ITEM_LIFETIME_FREQUENCY",
        "FILTER_OS",
        "FILTER_BROWSER",
        "FILTER_CARRIER",
        "FILTER_SITE_LANGUAGE",
        "FILTER_INVENTORY_FORMAT",
        "FILTER_ZIP_CODE",
        "FILTER_VIDEO_RATING_TIER",
        "FILTER_VIDEO_FORMAT_SUPPORT",
        "FILTER_VIDEO_SKIPPABLE_SUPPORT",
        "FILTER_VIDEO_CREATIVE_DURATION",
        "FILTER_PAGE_LAYOUT",
        "FILTER_VIDEO_AD_POSITION_IN_STREAM",
        "FILTER_AGE",
        "FILTER_GENDER",
        "FILTER_QUARTER",
        "FILTER_TRUEVIEW_CONVERSION_TYPE",
        "FILTER_MOBILE_GEO",
        "FILTER_MRAID_SUPPORT",
        "FILTER_ACTIVE_VIEW_EXPECTED_VIEWABILITY",
        "FILTER_VIDEO_CREATIVE_DURATION_SKIPPABLE",
        "FILTER_NIELSEN_COUNTRY_CODE",
        "FILTER_NIELSEN_DEVICE_ID",
        "FILTER_NIELSEN_GENDER",
        "FILTER_NIELSEN_AGE",
        "FILTER_INVENTORY_SOURCE_TYPE",
        "FILTER_CREATIVE_WIDTH",
        "FILTER_CREATIVE_HEIGHT",
        "FILTER_DFP_ORDER_ID",
        "FILTER_TRUEVIEW_AGE",
        "FILTER_TRUEVIEW_GENDER",
        "FILTER_TRUEVIEW_PARENTAL_STATUS",
        "FILTER_TRUEVIEW_REMARKETING_LIST",
        "FILTER_TRUEVIEW_INTEREST",
        "FILTER_TRUEVIEW_AD_GROUP_ID",
        "FILTER_TRUEVIEW_AD_GROUP_AD_ID",
        "FILTER_TRUEVIEW_IAR_LANGUAGE",
        "FILTER_TRUEVIEW_IAR_GENDER",
        "FILTER_TRUEVIEW_IAR_AGE",
        "FILTER_TRUEVIEW_IAR_CATEGORY",
        "FILTER_TRUEVIEW_IAR_COUNTRY",
        "FILTER_TRUEVIEW_IAR_CITY",
        "FILTER_TRUEVIEW_IAR_REGION",
        "FILTER_TRUEVIEW_IAR_ZIPCODE",
        "FILTER_TRUEVIEW_IAR_REMARKETING_LIST",
        "FILTER_TRUEVIEW_IAR_INTEREST",
        "FILTER_TRUEVIEW_IAR_PARENTAL_STATUS",
        "FILTER_TRUEVIEW_IAR_TIME_OF_DAY",
        "FILTER_TRUEVIEW_CUSTOM_AFFINITY",
        "FILTER_TRUEVIEW_CATEGORY",
        "FILTER_TRUEVIEW_KEYWORD",
        "FILTER_TRUEVIEW_PLACEMENT",
        "FILTER_TRUEVIEW_URL",
        "FILTER_TRUEVIEW_COUNTRY",
        "FILTER_TRUEVIEW_REGION",
        "FILTER_TRUEVIEW_CITY",
        "FILTER_TRUEVIEW_DMA",
        "FILTER_TRUEVIEW_ZIPCODE",
        "FILTER_NOT_SUPPORTED",
        "FILTER_MEDIA_PLAN",
        "FILTER_TRUEVIEW_IAR_YOUTUBE_CHANNEL",
        "FILTER_TRUEVIEW_IAR_YOUTUBE_VIDEO",
        "FILTER_SKIPPABLE_SUPPORT",
        "FILTER_COMPANION_CREATIVE_ID",
        "FILTER_BUDGET_SEGMENT_DESCRIPTION",
        "FILTER_FLOODLIGHT_ACTIVITY_ID",
        "FILTER_DEVICE_MODEL",
        "FILTER_DEVICE_MAKE",
        "FILTER_DEVICE_TYPE",
        "FILTER_CREATIVE_ATTRIBUTE",
        "FILTER_INVENTORY_COMMITMENT_TYPE",
        "FILTER_INVENTORY_RATE_TYPE",
        "FILTER_INVENTORY_DELIVERY_METHOD",
        "FILTER_INVENTORY_SOURCE_EXTERNAL_ID",
        "FILTER_AUTHORIZED_SELLER_STATE",
        "FILTER_VIDEO_DURATION_SECONDS_RANGE",
        "FILTER_PARTNER_NAME",
        "FILTER_PARTNER_STATUS",
        "FILTER_ADVERTISER_NAME",
        "FILTER_ADVERTISER_INTEGRATION_CODE",
        "FILTER_ADVERTISER_INTEGRATION_STATUS",
        "FILTER_CARRIER_NAME",
        "FILTER_CHANNEL_NAME",
        "FILTER_CITY_NAME",
        "FILTER_COMPANION_CREATIVE_NAME",
        "FILTER_USER_LIST_FIRST_PARTY_NAME",
        "FILTER_USER_LIST_THIRD_PARTY_NAME",
        "FILTER_NIELSEN_RESTATEMENT_DATE",
        "FILTER_NIELSEN_DATE_RANGE",
        "FILTER_INSERTION_ORDER_NAME",
        "FILTER_REGION_NAME",
        "FILTER_DMA_NAME",
        "FILTER_TRUEVIEW_IAR_REGION_NAME",
        "FILTER_TRUEVIEW_DMA_NAME",
        "FILTER_TRUEVIEW_REGION_NAME",
        "FILTER_ACTIVE_VIEW_CUSTOM_METRIC_ID",
        "FILTER_ACTIVE_VIEW_CUSTOM_METRIC_NAME",
        "FILTER_AD_TYPE",
        "FILTER_ALGORITHM",
        "FILTER_ALGORITHM_ID",
        "FILTER_AMP_PAGE_REQUEST",
        "FILTER_ANONYMOUS_INVENTORY_MODELING",
        "FILTER_APP_URL",
        "FILTER_APP_URL_EXCLUDED",
        "FILTER_ATTRIBUTED_USERLIST",
        "FILTER_ATTRIBUTED_USERLIST_COST",
        "FILTER_ATTRIBUTED_USERLIST_TYPE",
        "FILTER_ATTRIBUTION_MODEL",
        "FILTER_AUDIENCE_LIST",
        "FILTER_AUDIENCE_LIST_COST",
        "FILTER_AUDIENCE_LIST_TYPE",
        "FILTER_AUDIENCE_NAME",
        "FILTER_AUDIENCE_TYPE",
        "FILTER_BILLABLE_OUTCOME",
        "FILTER_BRAND_LIFT_TYPE",
        "FILTER_CHANNEL_TYPE",
        "FILTER_CM_PLACEMENT_ID",
        "FILTER_CONVERSION_SOURCE",
        "FILTER_CONVERSION_SOURCE_ID",
        "FILTER_COUNTRY_ID",
        "FILTER_CREATIVE",
        "FILTER_CREATIVE_ASSET",
        "FILTER_CREATIVE_INTEGRATION_CODE",
        "FILTER_CREATIVE_RENDERED_IN_AMP",
        "FILTER_CREATIVE_SOURCE",
        "FILTER_CREATIVE_STATUS",
        "FILTER_DATA_PROVIDER_NAME",
        "FILTER_DETAILED_DEMOGRAPHICS",
        "FILTER_DETAILED_DEMOGRAPHICS_ID",
        "FILTER_DEVICE",
        "FILTER_GAM_INSERTION_ORDER",
        "FILTER_GAM_LINE_ITEM",
        "FILTER_GAM_LINE_ITEM_ID",
        "FILTER_DIGITAL_CONTENT_LABEL",
        "FILTER_DOMAIN",
        "FILTER_ELIGIBLE_COOKIES_ON_FIRST_PARTY_AUDIENCE_LIST",
        "FILTER_ELIGIBLE_COOKIES_ON_THIRD_PARTY_AUDIENCE_LIST_AND_INTEREST",
        "FILTER_EXCHANGE",
        "FILTER_EXCHANGE_CODE",
        "FILTER_EXTENSION",
        "FILTER_EXTENSION_STATUS",
        "FILTER_EXTENSION_TYPE",
        "FILTER_FIRST_PARTY_AUDIENCE_LIST_COST",
        "FILTER_FIRST_PARTY_AUDIENCE_LIST_TYPE",
        "FILTER_FLOODLIGHT_ACTIVITY",
        "FILTER_FORMAT",
        "FILTER_GMAIL_AGE",
        "FILTER_GMAIL_CITY",
        "FILTER_GMAIL_COUNTRY",
        "FILTER_GMAIL_COUNTRY_NAME",
        "FILTER_GMAIL_DEVICE_TYPE",
        "FILTER_GMAIL_DEVICE_TYPE_NAME",
        "FILTER_GMAIL_GENDER",
        "FILTER_GMAIL_REGION",
        "FILTER_GMAIL_REMARKETING_LIST",
        "FILTER_HOUSEHOLD_INCOME",
        "FILTER_IMPRESSION_COUNTING_METHOD",
        "FILTER_YOUTUBE_PROGRAMMATIC_GUARANTEED_INSERTION_ORDER",
        "FILTER_INSERTION_ORDER_INTEGRATION_CODE",
        "FILTER_INSERTION_ORDER_STATUS",
        "FILTER_INTEREST",
        "FILTER_INVENTORY_SOURCE_GROUP",
        "FILTER_INVENTORY_SOURCE_GROUP_ID",
        "FILTER_INVENTORY_SOURCE_ID",
        "FILTER_INVENTORY_SOURCE_NAME",
        "FILTER_LIFE_EVENT",
        "FILTER_LIFE_EVENTS",
        "FILTER_LINE_ITEM_INTEGRATION_CODE",
        "FILTER_LINE_ITEM_NAME",
        "FILTER_LINE_ITEM_STATUS",
        "FILTER_MATCH_RATIO",
        "FILTER_MEASUREMENT_SOURCE",
        "FILTER_MEDIA_PLAN_NAME",
        "FILTER_PARENTAL_STATUS",
        "FILTER_PLACEMENT_ALL_YOUTUBE_CHANNELS",
        "FILTER_PLATFORM",
        "FILTER_PLAYBACK_METHOD",
        "FILTER_POSITION_IN_CONTENT",
        "FILTER_PUBLISHER_PROPERTY",
        "FILTER_PUBLISHER_PROPERTY_ID",
        "FILTER_PUBLISHER_PROPERTY_SECTION",
        "FILTER_PUBLISHER_PROPERTY_SECTION_ID",
        "FILTER_REFUND_REASON",
        "FILTER_REMARKETING_LIST",
        "FILTER_REWARDED",
        "FILTER_SENSITIVE_CATEGORY",
        "FILTER_SERVED_PIXEL_DENSITY",
        "FILTER_TARGETED_DATA_PROVIDERS",
        "FILTER_THIRD_PARTY_AUDIENCE_LIST_COST",
        "FILTER_THIRD_PARTY_AUDIENCE_LIST_TYPE",
        "FILTER_TRUEVIEW_AD",
        "FILTER_TRUEVIEW_AD_GROUP",
        "FILTER_TRUEVIEW_DETAILED_DEMOGRAPHICS",
        "FILTER_TRUEVIEW_DETAILED_DEMOGRAPHICS_ID",
        "FILTER_TRUEVIEW_HOUSEHOLD_INCOME",
        "FILTER_TRUEVIEW_IAR_COUNTRY_NAME",
        "FILTER_TRUEVIEW_REMARKETING_LIST_NAME",
        "FILTER_VARIANT_ID",
        "FILTER_VARIANT_NAME",
        "FILTER_VARIANT_VERSION",
        "FILTER_VERIFICATION_VIDEO_PLAYER_SIZE",
        "FILTER_VERIFICATION_VIDEO_POSITION",
        "FILTER_VIDEO_COMPANION_CREATIVE_SIZE",
        "FILTER_VIDEO_CONTINUOUS_PLAY",
        "FILTER_VIDEO_DURATION",
        "FILTER_YOUTUBE_ADAPTED_AUDIENCE_LIST",
        "FILTER_YOUTUBE_AD_VIDEO",
        "FILTER_YOUTUBE_AD_VIDEO_ID",
        "FILTER_YOUTUBE_CHANNEL",
        "FILTER_YOUTUBE_PROGRAMMATIC_GUARANTEED_ADVERTISER",
        "FILTER_YOUTUBE_PROGRAMMATIC_GUARANTEED_PARTNER",
        "FILTER_YOUTUBE_VIDEO",
        "FILTER_ZIP_POSTAL_CODE",
        "FILTER_PLACEMENT_NAME_ALL_YOUTUBE_CHANNELS",
        "FILTER_TRUEVIEW_PLACEMENT_ID",
        "FILTER_PATH_PATTERN_ID",
        "FILTER_PATH_EVENT_INDEX",
        "FILTER_EVENT_TYPE",
        "FILTER_CHANNEL_GROUPING",
        "FILTER_OM_SDK_AVAILABLE",
        "FILTER_DATA_SOURCE",
        "FILTER_CM360_PLACEMENT_ID",
        "FILTER_TRUEVIEW_CLICK_TYPE_NAME",
        "FILTER_TRUEVIEW_AD_TYPE_NAME",
        "FILTER_VIDEO_CONTENT_DURATION",
        "FILTER_MATCHED_GENRE_TARGET",
        "FILTER_VIDEO_CONTENT_LIVE_STREAM",
        "FILTER_BUDGET_SEGMENT_TYPE",
        "FILTER_BUDGET_SEGMENT_BUDGET",
        "FILTER_BUDGET_SEGMENT_START_DATE",
        "FILTER_BUDGET_SEGMENT_END_DATE",
        "FILTER_BUDGET_SEGMENT_PACING_PERCENTAGE",
        "FILTER_LINE_ITEM_BUDGET",
        "FILTER_LINE_ITEM_START_DATE",
        "FILTER_LINE_ITEM_END_DATE",
        "FILTER_INSERTION_ORDER_GOAL_TYPE",
        "FILTER_LINE_ITEM_PACING_PERCENTAGE",
        "FILTER_INSERTION_ORDER_GOAL_VALUE",
        "FILTER_OMID_CAPABLE",
        "FILTER_VENDOR_MEASUREMENT_MODE",
        "FILTER_IMPRESSION_LOSS_REJECTION_REASON",
        "FILTER_VERIFICATION_VIDEO_PLAYER_SIZE_START",
        "FILTER_VERIFICATION_VIDEO_PLAYER_SIZE_FIRST_QUARTILE",
        "FILTER_VERIFICATION_VIDEO_PLAYER_SIZE_MID_POINT",
        "FILTER_VERIFICATION_VIDEO_PLAYER_SIZE_THIRD_QUARTILE",
        "FILTER_VERIFICATION_VIDEO_PLAYER_SIZE_COMPLETE",
        "FILTER_VERIFICATION_VIDEO_RESIZED",
        "FILTER_VERIFICATION_AUDIBILITY_START",
        "FILTER_VERIFICATION_AUDIBILITY_COMPLETE",
        "FILTER_MEDIA_TYPE",
        "FILTER_AUDIO_FEED_TYPE_NAME",
        "FILTER_TRUEVIEW_TARGETING_EXPANSION",
        "FILTER_PUBLISHER_TRAFFIC_SOURCE",
    ]
    match: typing_extensions.Literal[
        "UNKNOWN", "EXACT", "PARTIAL", "BEGINS_WITH", "WILDCARD_EXPRESSION"
    ]
    values: _list[str]

@typing.type_check_only
class Query(typing_extensions.TypedDict, total=False):
    kind: str
    metadata: QueryMetadata
    params: Parameters
    queryId: str
    reportDataEndTimeMs: str
    reportDataStartTimeMs: str
    schedule: QuerySchedule
    timezoneCode: str

@typing.type_check_only
class QueryMetadata(typing_extensions.TypedDict, total=False):
    dataRange: typing_extensions.Literal[
        "CUSTOM_DATES",
        "CURRENT_DAY",
        "PREVIOUS_DAY",
        "WEEK_TO_DATE",
        "MONTH_TO_DATE",
        "QUARTER_TO_DATE",
        "YEAR_TO_DATE",
        "PREVIOUS_WEEK",
        "PREVIOUS_HALF_MONTH",
        "PREVIOUS_MONTH",
        "PREVIOUS_QUARTER",
        "PREVIOUS_YEAR",
        "LAST_7_DAYS",
        "LAST_30_DAYS",
        "LAST_90_DAYS",
        "LAST_365_DAYS",
        "ALL_TIME",
        "LAST_14_DAYS",
        "TYPE_NOT_SUPPORTED",
        "LAST_60_DAYS",
    ]
    format: typing_extensions.Literal["CSV", "EXCEL_CSV", "XLSX"]
    googleCloudStoragePathForLatestReport: str
    googleDrivePathForLatestReport: str
    latestReportRunTimeMs: str
    locale: str
    reportCount: int
    running: bool
    sendNotification: bool
    shareEmailAddress: _list[str]
    title: str

@typing.type_check_only
class QuerySchedule(typing_extensions.TypedDict, total=False):
    endTimeMs: str
    frequency: typing_extensions.Literal[
        "ONE_TIME", "DAILY", "WEEKLY", "SEMI_MONTHLY", "MONTHLY", "QUARTERLY", "YEARLY"
    ]
    nextRunMinuteOfDay: int
    nextRunTimezoneCode: str
    startTimeMs: str

@typing.type_check_only
class Report(typing_extensions.TypedDict, total=False):
    key: ReportKey
    metadata: ReportMetadata
    params: Parameters

@typing.type_check_only
class ReportFailure(typing_extensions.TypedDict, total=False):
    errorCode: typing_extensions.Literal[
        "AUTHENTICATION_ERROR",
        "UNAUTHORIZED_API_ACCESS",
        "SERVER_ERROR",
        "VALIDATION_ERROR",
        "REPORTING_FATAL_ERROR",
        "REPORTING_TRANSIENT_ERROR",
        "REPORTING_IMCOMPATIBLE_METRICS",
        "REPORTING_ILLEGAL_FILENAME",
        "REPORTING_QUERY_NOT_FOUND",
        "REPORTING_BUCKET_NOT_FOUND",
        "REPORTING_CREATE_BUCKET_FAILED",
        "REPORTING_DELETE_BUCKET_FAILED",
        "REPORTING_UPDATE_BUCKET_PERMISSION_FAILED",
        "REPORTING_WRITE_BUCKET_OBJECT_FAILED",
        "DEPRECATED_REPORTING_INVALID_QUERY",
        "REPORTING_INVALID_QUERY_TOO_MANY_UNFILTERED_LARGE_GROUP_BYS",
        "REPORTING_INVALID_QUERY_TITLE_MISSING",
        "REPORTING_INVALID_QUERY_MISSING_PARTNER_AND_ADVERTISER_FILTERS",
    ]

@typing.type_check_only
class ReportKey(typing_extensions.TypedDict, total=False):
    queryId: str
    reportId: str

@typing.type_check_only
class ReportMetadata(typing_extensions.TypedDict, total=False):
    googleCloudStoragePath: str
    reportDataEndTimeMs: str
    reportDataStartTimeMs: str
    status: ReportStatus

@typing.type_check_only
class ReportStatus(typing_extensions.TypedDict, total=False):
    failure: ReportFailure
    finishTimeMs: str
    format: typing_extensions.Literal["CSV", "EXCEL_CSV", "XLSX"]
    state: typing_extensions.Literal["RUNNING", "DONE", "FAILED"]

@typing.type_check_only
class Rule(typing_extensions.TypedDict, total=False):
    disjunctiveMatchStatements: _list[DisjunctiveMatchStatement]
    name: str

@typing.type_check_only
class RunQueryRequest(typing_extensions.TypedDict, total=False):
    dataRange: typing_extensions.Literal[
        "CUSTOM_DATES",
        "CURRENT_DAY",
        "PREVIOUS_DAY",
        "WEEK_TO_DATE",
        "MONTH_TO_DATE",
        "QUARTER_TO_DATE",
        "YEAR_TO_DATE",
        "PREVIOUS_WEEK",
        "PREVIOUS_HALF_MONTH",
        "PREVIOUS_MONTH",
        "PREVIOUS_QUARTER",
        "PREVIOUS_YEAR",
        "LAST_7_DAYS",
        "LAST_30_DAYS",
        "LAST_90_DAYS",
        "LAST_365_DAYS",
        "ALL_TIME",
        "LAST_14_DAYS",
        "TYPE_NOT_SUPPORTED",
        "LAST_60_DAYS",
    ]
    reportDataEndTimeMs: str
    reportDataStartTimeMs: str
    timezoneCode: str



import typing

import typing_extensions

_list = list

@typing.type_check_only
class BatchDeleteJobsRequest(typing_extensions.TypedDict, total=False):
    filter: str

AlternativeBucketRange = typing_extensions.TypedDict(
    "AlternativeBucketRange",
    {
        "from": float,
        "to": float,
    },
    total=False,
)

@typing.type_check_only
class BucketRange(AlternativeBucketRange): ...

@typing.type_check_only
class BucketizedCount(typing_extensions.TypedDict, total=False):
    count: int
    range: BucketRange

@typing.type_check_only
class CommuteInfo(typing_extensions.TypedDict, total=False):
    jobLocation: JobLocation
    travelDuration: str

@typing.type_check_only
class CommutePreference(typing_extensions.TypedDict, total=False):
    allowNonStreetLevelAddress: bool
    departureHourLocal: int
    method: typing_extensions.Literal[
        "COMMUTE_METHOD_UNSPECIFIED", "DRIVING", "TRANSIT"
    ]
    roadTraffic: typing_extensions.Literal[
        "ROAD_TRAFFIC_UNSPECIFIED", "TRAFFIC_FREE", "BUSY_HOUR"
    ]
    startLocation: LatLng
    travelTime: str

@typing.type_check_only
class Company(typing_extensions.TypedDict, total=False):
    careerPageLink: str
    companyInfoSources: _list[CompanyInfoSource]
    companySize: typing_extensions.Literal[
        "COMPANY_SIZE_UNSPECIFIED",
        "MINI",
        "SMALL",
        "SMEDIUM",
        "MEDIUM",
        "BIG",
        "BIGGER",
        "GIANT",
    ]
    disableLocationOptimization: bool
    displayName: str
    distributorBillingCompanyId: str
    distributorCompanyId: str
    eeoText: str
    hiringAgency: bool
    hqLocation: str
    imageUrl: str
    keywordSearchableCustomAttributes: _list[str]
    keywordSearchableCustomFields: _list[int]
    name: str
    structuredCompanyHqLocation: JobLocation
    suspended: bool
    title: str
    website: str

@typing.type_check_only
class CompanyInfoSource(typing_extensions.TypedDict, total=False):
    freebaseMid: str
    gplusId: str
    mapsCid: str
    unknownTypeId: str

@typing.type_check_only
class CompensationEntry(typing_extensions.TypedDict, total=False):
    amount: Money
    description: str
    expectedUnitsPerYear: float
    range: CompensationRange
    type: typing_extensions.Literal[
        "COMPENSATION_TYPE_UNSPECIFIED",
        "BASE",
        "BONUS",
        "SIGNING_BONUS",
        "EQUITY",
        "PROFIT_SHARING",
        "COMMISSIONS",
        "TIPS",
        "OTHER_COMPENSATION_TYPE",
    ]
    unit: typing_extensions.Literal[
        "COMPENSATION_UNIT_UNSPECIFIED",
        "HOURLY",
        "DAILY",
        "WEEKLY",
        "MONTHLY",
        "YEARLY",
        "ONE_TIME",
        "OTHER_COMPENSATION_UNIT",
    ]

@typing.type_check_only
class CompensationFilter(typing_extensions.TypedDict, total=False):
    includeJobsWithUnspecifiedCompensationRange: bool
    range: CompensationRange
    type: typing_extensions.Literal[
        "FILTER_TYPE_UNSPECIFIED",
        "UNIT_ONLY",
        "UNIT_AND_AMOUNT",
        "ANNUALIZED_BASE_AMOUNT",
        "ANNUALIZED_TOTAL_AMOUNT",
    ]
    units: _list[str]

@typing.type_check_only
class CompensationHistogramRequest(typing_extensions.TypedDict, total=False):
    bucketingOption: NumericBucketingOption
    type: typing_extensions.Literal[
        "COMPENSATION_HISTOGRAM_REQUEST_TYPE_UNSPECIFIED",
        "BASE",
        "ANNUALIZED_BASE",
        "ANNUALIZED_TOTAL",
    ]

@typing.type_check_only
class CompensationHistogramResult(typing_extensions.TypedDict, total=False):
    result: NumericBucketingResult
    type: typing_extensions.Literal[
        "COMPENSATION_HISTOGRAM_REQUEST_TYPE_UNSPECIFIED",
        "BASE",
        "ANNUALIZED_BASE",
        "ANNUALIZED_TOTAL",
    ]

@typing.type_check_only
class CompensationInfo(typing_extensions.TypedDict, total=False):
    amount: Money
    annualizedBaseCompensationRange: CompensationRange
    annualizedTotalCompensationRange: CompensationRange
    entries: _list[CompensationEntry]
    max: Money
    min: Money
    type: typing_extensions.Literal[
        "JOB_COMPENSATION_TYPE_UNSPECIFIED",
        "HOURLY",
        "SALARY",
        "PER_PROJECT",
        "COMMISSION",
        "OTHER_TYPE",
    ]

@typing.type_check_only
class CompensationRange(typing_extensions.TypedDict, total=False):
    max: Money
    min: Money

@typing.type_check_only
class CompleteQueryResponse(typing_extensions.TypedDict, total=False):
    completionResults: _list[CompletionResult]
    metadata: ResponseMetadata

@typing.type_check_only
class CompletionResult(typing_extensions.TypedDict, total=False):
    imageUrl: str
    suggestion: str
    type: typing_extensions.Literal[
        "COMPLETION_TYPE_UNSPECIFIED", "JOB_TITLE", "COMPANY_NAME", "COMBINED"
    ]

@typing.type_check_only
class CreateJobRequest(typing_extensions.TypedDict, total=False):
    disableStreetAddressResolution: bool
    job: Job
    processingOptions: JobProcessingOptions

@typing.type_check_only
class CustomAttribute(typing_extensions.TypedDict, total=False):
    filterable: bool
    longValue: str
    stringValues: StringValues

@typing.type_check_only
class CustomAttributeHistogramRequest(typing_extensions.TypedDict, total=False):
    key: str
    longValueHistogramBucketingOption: NumericBucketingOption
    stringValueHistogram: bool

@typing.type_check_only
class CustomAttributeHistogramResult(typing_extensions.TypedDict, total=False):
    key: str
    longValueHistogramResult: NumericBucketingResult
    stringValueHistogramResult: dict[str, typing.Any]

@typing.type_check_only
class CustomField(typing_extensions.TypedDict, total=False):
    values: _list[str]

@typing.type_check_only
class CustomFieldFilter(typing_extensions.TypedDict, total=False):
    queries: _list[str]
    type: typing_extensions.Literal["FILTER_TYPE_UNSPECIFIED", "OR", "AND", "NOT"]

@typing.type_check_only
class Date(typing_extensions.TypedDict, total=False):
    day: int
    month: int
    year: int

@typing.type_check_only
class DeleteJobsByFilterRequest(typing_extensions.TypedDict, total=False):
    disableFastProcess: bool
    filter: Filter

@typing.type_check_only
class DeviceInfo(typing_extensions.TypedDict, total=False):
    deviceType: typing_extensions.Literal[
        "DEVICE_TYPE_UNSPECIFIED", "WEB", "MOBILE_WEB", "ANDROID", "IOS", "BOT", "OTHER"
    ]
    id: str

@typing.type_check_only
class Empty(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class ExtendedCompensationFilter(typing_extensions.TypedDict, total=False):
    compensationRange: ExtendedCompensationInfoCompensationRange
    compensationUnits: _list[str]
    currency: str
    includeJobWithUnspecifiedCompensationRange: bool
    type: typing_extensions.Literal[
        "FILTER_TYPE_UNSPECIFIED",
        "UNIT_ONLY",
        "UNIT_AND_AMOUNT",
        "ANNUALIZED_BASE_AMOUNT",
        "ANNUALIZED_TOTAL_AMOUNT",
    ]

@typing.type_check_only
class ExtendedCompensationInfo(typing_extensions.TypedDict, total=False):
    annualizedBaseCompensationRange: ExtendedCompensationInfoCompensationRange
    annualizedBaseCompensationUnspecified: bool
    annualizedTotalCompensationRange: ExtendedCompensationInfoCompensationRange
    annualizedTotalCompensationUnspecified: bool
    currency: str
    entries: _list[ExtendedCompensationInfoCompensationEntry]

@typing.type_check_only
class ExtendedCompensationInfoCompensationEntry(
    typing_extensions.TypedDict, total=False
):
    amount: ExtendedCompensationInfoDecimal
    description: str
    expectedUnitsPerYear: ExtendedCompensationInfoDecimal
    range: ExtendedCompensationInfoCompensationRange
    type: typing_extensions.Literal[
        "EXTENDED_COMPENSATION_TYPE_UNSPECIFIED",
        "BASE",
        "BONUS",
        "SIGNING_BONUS",
        "EQUITY",
        "PROFIT_SHARING",
        "COMMISSIONS",
        "TIPS",
        "OTHER_COMPENSATION_TYPE",
    ]
    unit: typing_extensions.Literal[
        "EXTENDED_COMPENSATION_UNIT_UNSPECIFIED",
        "HOURLY",
        "DAILY",
        "WEEKLY",
        "MONTHLY",
        "YEARLY",
        "ONE_TIME",
        "OTHER_COMPENSATION_UNIT",
    ]
    unspecified: bool

@typing.type_check_only
class ExtendedCompensationInfoCompensationRange(
    typing_extensions.TypedDict, total=False
):
    max: ExtendedCompensationInfoDecimal
    min: ExtendedCompensationInfoDecimal

@typing.type_check_only
class ExtendedCompensationInfoDecimal(typing_extensions.TypedDict, total=False):
    micros: int
    units: str

@typing.type_check_only
class Filter(typing_extensions.TypedDict, total=False):
    requisitionId: str

@typing.type_check_only
class GetHistogramRequest(typing_extensions.TypedDict, total=False):
    allowBroadening: bool
    filters: JobFilters
    query: JobQuery
    requestMetadata: RequestMetadata
    searchTypes: _list[str]

@typing.type_check_only
class GetHistogramResponse(typing_extensions.TypedDict, total=False):
    metadata: ResponseMetadata
    results: _list[HistogramResult]

@typing.type_check_only
class GoogleCloudTalentV4BatchCreateJobsResponse(
    typing_extensions.TypedDict, total=False
):
    jobResults: _list[GoogleCloudTalentV4JobResult]

@typing.type_check_only
class GoogleCloudTalentV4BatchDeleteJobsResponse(
    typing_extensions.TypedDict, total=False
):
    jobResults: _list[GoogleCloudTalentV4JobResult]

@typing.type_check_only
class GoogleCloudTalentV4BatchOperationMetadata(
    typing_extensions.TypedDict, total=False
):
    createTime: str
    endTime: str
    failureCount: int
    state: typing_extensions.Literal[
        "STATE_UNSPECIFIED",
        "INITIALIZING",
        "PROCESSING",
        "SUCCEEDED",
        "FAILED",
        "CANCELLING",
        "CANCELLED",
    ]
    stateDescription: str
    successCount: int
    totalCount: int
    updateTime: str

@typing.type_check_only
class GoogleCloudTalentV4BatchUpdateJobsResponse(
    typing_extensions.TypedDict, total=False
):
    jobResults: _list[GoogleCloudTalentV4JobResult]

@typing.type_check_only
class GoogleCloudTalentV4CompensationInfo(typing_extensions.TypedDict, total=False):
    annualizedBaseCompensationRange: GoogleCloudTalentV4CompensationInfoCompensationRange
    annualizedTotalCompensationRange: GoogleCloudTalentV4CompensationInfoCompensationRange
    entries: _list[GoogleCloudTalentV4CompensationInfoCompensationEntry]

@typing.type_check_only
class GoogleCloudTalentV4CompensationInfoCompensationEntry(
    typing_extensions.TypedDict, total=False
):
    amount: Money
    description: str
    expectedUnitsPerYear: float
    range: GoogleCloudTalentV4CompensationInfoCompensationRange
    type: typing_extensions.Literal[
        "COMPENSATION_TYPE_UNSPECIFIED",
        "BASE",
        "BONUS",
        "SIGNING_BONUS",
        "EQUITY",
        "PROFIT_SHARING",
        "COMMISSIONS",
        "TIPS",
        "OTHER_COMPENSATION_TYPE",
    ]
    unit: typing_extensions.Literal[
        "COMPENSATION_UNIT_UNSPECIFIED",
        "HOURLY",
        "DAILY",
        "WEEKLY",
        "MONTHLY",
        "YEARLY",
        "ONE_TIME",
        "OTHER_COMPENSATION_UNIT",
    ]

@typing.type_check_only
class GoogleCloudTalentV4CompensationInfoCompensationRange(
    typing_extensions.TypedDict, total=False
):
    maxCompensation: Money
    minCompensation: Money

@typing.type_check_only
class GoogleCloudTalentV4CustomAttribute(typing_extensions.TypedDict, total=False):
    filterable: bool
    keywordSearchable: bool
    longValues: _list[str]
    stringValues: _list[str]

@typing.type_check_only
class GoogleCloudTalentV4Job(typing_extensions.TypedDict, total=False):
    addresses: _list[str]
    applicationInfo: GoogleCloudTalentV4JobApplicationInfo
    company: str
    companyDisplayName: str
    compensationInfo: GoogleCloudTalentV4CompensationInfo
    customAttributes: dict[str, typing.Any]
    degreeTypes: _list[str]
    department: str
    derivedInfo: GoogleCloudTalentV4JobDerivedInfo
    description: str
    employmentTypes: _list[str]
    incentives: str
    jobBenefits: _list[str]
    jobEndTime: str
    jobLevel: typing_extensions.Literal[
        "JOB_LEVEL_UNSPECIFIED",
        "ENTRY_LEVEL",
        "EXPERIENCED",
        "MANAGER",
        "DIRECTOR",
        "EXECUTIVE",
    ]
    jobStartTime: str
    languageCode: str
    name: str
    postingCreateTime: str
    postingExpireTime: str
    postingPublishTime: str
    postingRegion: typing_extensions.Literal[
        "POSTING_REGION_UNSPECIFIED", "ADMINISTRATIVE_AREA", "NATION", "TELECOMMUTE"
    ]
    postingUpdateTime: str
    processingOptions: GoogleCloudTalentV4JobProcessingOptions
    promotionValue: int
    qualifications: str
    requisitionId: str
    responsibilities: str
    title: str
    visibility: typing_extensions.Literal[
        "VISIBILITY_UNSPECIFIED",
        "ACCOUNT_ONLY",
        "SHARED_WITH_GOOGLE",
        "SHARED_WITH_PUBLIC",
    ]

@typing.type_check_only
class GoogleCloudTalentV4JobApplicationInfo(typing_extensions.TypedDict, total=False):
    emails: _list[str]
    instruction: str
    uris: _list[str]

@typing.type_check_only
class GoogleCloudTalentV4JobDerivedInfo(typing_extensions.TypedDict, total=False):
    jobCategories: _list[str]
    locations: _list[GoogleCloudTalentV4Location]

@typing.type_check_only
class GoogleCloudTalentV4JobProcessingOptions(typing_extensions.TypedDict, total=False):
    disableStreetAddressResolution: bool
    htmlSanitization: typing_extensions.Literal[
        "HTML_SANITIZATION_UNSPECIFIED",
        "HTML_SANITIZATION_DISABLED",
        "SIMPLE_FORMATTING_ONLY",
    ]

@typing.type_check_only
class GoogleCloudTalentV4JobResult(typing_extensions.TypedDict, total=False):
    job: GoogleCloudTalentV4Job
    status: Status

@typing.type_check_only
class GoogleCloudTalentV4Location(typing_extensions.TypedDict, total=False):
    latLng: LatLng
    locationType: typing_extensions.Literal[
        "LOCATION_TYPE_UNSPECIFIED",
        "COUNTRY",
        "ADMINISTRATIVE_AREA",
        "SUB_ADMINISTRATIVE_AREA",
        "LOCALITY",
        "POSTAL_CODE",
        "SUB_LOCALITY",
        "SUB_LOCALITY_1",
        "SUB_LOCALITY_2",
        "NEIGHBORHOOD",
        "STREET_ADDRESS",
    ]
    postalAddress: PostalAddress
    radiusMiles: float

@typing.type_check_only
class HistogramFacets(typing_extensions.TypedDict, total=False):
    compensationHistogramFacets: _list[CompensationHistogramRequest]
    customAttributeHistogramFacets: _list[CustomAttributeHistogramRequest]
    simpleHistogramFacets: _list[str]

@typing.type_check_only
class HistogramResult(typing_extensions.TypedDict, total=False):
    searchType: typing_extensions.Literal[
        "JOB_FIELD_UNSPECIFIED",
        "COMPANY_ID",
        "EMPLOYMENT_TYPE",
        "COMPANY_SIZE",
        "DATE_PUBLISHED",
        "CUSTOM_FIELD_1",
        "CUSTOM_FIELD_2",
        "CUSTOM_FIELD_3",
        "CUSTOM_FIELD_4",
        "CUSTOM_FIELD_5",
        "CUSTOM_FIELD_6",
        "CUSTOM_FIELD_7",
        "CUSTOM_FIELD_8",
        "CUSTOM_FIELD_9",
        "CUSTOM_FIELD_10",
        "CUSTOM_FIELD_11",
        "CUSTOM_FIELD_12",
        "CUSTOM_FIELD_13",
        "CUSTOM_FIELD_14",
        "CUSTOM_FIELD_15",
        "CUSTOM_FIELD_16",
        "CUSTOM_FIELD_17",
        "CUSTOM_FIELD_18",
        "CUSTOM_FIELD_19",
        "CUSTOM_FIELD_20",
        "EDUCATION_LEVEL",
        "EXPERIENCE_LEVEL",
        "ADMIN1",
        "COUNTRY",
        "CITY",
        "LOCALE",
        "LANGUAGE",
        "CATEGORY",
        "CITY_COORDINATE",
        "ADMIN1_COUNTRY",
        "COMPANY_TITLE",
        "COMPANY_DISPLAY_NAME",
        "BASE_COMPENSATION_UNIT",
    ]
    values: dict[str, typing.Any]

@typing.type_check_only
class HistogramResults(typing_extensions.TypedDict, total=False):
    compensationHistogramResults: _list[CompensationHistogramResult]
    customAttributeHistogramResults: _list[CustomAttributeHistogramResult]
    simpleHistogramResults: _list[HistogramResult]

@typing.type_check_only
class Job(typing_extensions.TypedDict, total=False):
    applicationEmailList: _list[str]
    applicationInstruction: str
    applicationUrls: _list[str]
    benefits: _list[str]
    companyDisplayName: str
    companyName: str
    companyTitle: str
    compensationInfo: CompensationInfo
    createTime: str
    customAttributes: dict[str, typing.Any]
    department: str
    description: str
    distributorCompanyId: str
    educationLevels: _list[str]
    employmentTypes: _list[str]
    endDate: Date
    expireTime: str
    expiryDate: Date
    extendedCompensationInfo: ExtendedCompensationInfo
    filterableCustomFields: dict[str, typing.Any]
    incentives: str
    jobLocations: _list[JobLocation]
    jobTitle: str
    languageCode: str
    level: typing_extensions.Literal[
        "JOB_LEVEL_UNSPECIFIED",
        "ENTRY_LEVEL",
        "EXPERIENCED",
        "MANAGER",
        "DIRECTOR",
        "EXECUTIVE",
    ]
    locations: _list[str]
    name: str
    promotionValue: int
    publishDate: Date
    qualifications: str
    referenceUrl: str
    region: typing_extensions.Literal[
        "REGION_UNSPECIFIED", "STATE_WIDE", "NATION_WIDE", "TELECOMMUTE"
    ]
    requisitionId: str
    responsibilities: str
    startDate: Date
    unindexedCustomFields: dict[str, typing.Any]
    updateTime: str
    visibility: typing_extensions.Literal[
        "JOB_VISIBILITY_UNSPECIFIED", "PRIVATE", "GOOGLE", "PUBLIC"
    ]

@typing.type_check_only
class JobFilters(typing_extensions.TypedDict, total=False):
    categories: _list[str]
    commuteFilter: CommutePreference
    companyNames: _list[str]
    companyTitles: _list[str]
    compensationFilter: CompensationFilter
    customAttributeFilter: str
    customFieldFilters: dict[str, typing.Any]
    disableSpellCheck: bool
    employmentTypes: _list[str]
    extendedCompensationFilter: ExtendedCompensationFilter
    languageCodes: _list[str]
    locationFilters: _list[LocationFilter]
    publishDateRange: typing_extensions.Literal[
        "DATE_RANGE_UNSPECIFIED",
        "PAST_24_HOURS",
        "PAST_WEEK",
        "PAST_MONTH",
        "PAST_YEAR",
        "PAST_3_DAYS",
    ]
    query: str
    tenantJobOnly: bool

@typing.type_check_only
class JobLocation(typing_extensions.TypedDict, total=False):
    latLng: LatLng
    locationType: typing_extensions.Literal[
        "LOCATION_TYPE_UNSPECIFIED",
        "COUNTRY",
        "ADMINISTRATIVE_AREA",
        "SUB_ADMINISTRATIVE_AREA",
        "LOCALITY",
        "POSTAL_CODE",
        "SUB_LOCALITY",
        "SUB_LOCALITY_1",
        "SUB_LOCALITY_2",
        "NEIGHBORHOOD",
        "STREET_ADDRESS",
    ]
    postalAddress: PostalAddress
    radiusMeters: float

@typing.type_check_only
class JobProcessingOptions(typing_extensions.TypedDict, total=False):
    disableStreetAddressResolution: bool
    htmlSanitization: typing_extensions.Literal[
        "HTML_SANITIZATION_UNSPECIFIED",
        "HTML_SANITIZATION_DISABLED",
        "SIMPLE_FORMATTING_ONLY",
    ]

@typing.type_check_only
class JobQuery(typing_extensions.TypedDict, total=False):
    categories: _list[str]
    commuteFilter: CommutePreference
    companyDisplayNames: _list[str]
    companyNames: _list[str]
    compensationFilter: CompensationFilter
    customAttributeFilter: str
    disableSpellCheck: bool
    employmentTypes: _list[str]
    languageCodes: _list[str]
    locationFilters: _list[LocationFilter]
    publishDateRange: typing_extensions.Literal[
        "DATE_RANGE_UNSPECIFIED",
        "PAST_24_HOURS",
        "PAST_WEEK",
        "PAST_MONTH",
        "PAST_YEAR",
        "PAST_3_DAYS",
    ]
    query: str

@typing.type_check_only
class LatLng(typing_extensions.TypedDict, total=False):
    latitude: float
    longitude: float

@typing.type_check_only
class ListCompaniesResponse(typing_extensions.TypedDict, total=False):
    companies: _list[Company]
    metadata: ResponseMetadata
    nextPageToken: str

@typing.type_check_only
class ListCompanyJobsResponse(typing_extensions.TypedDict, total=False):
    jobs: _list[Job]
    metadata: ResponseMetadata
    nextPageToken: str
    totalSize: str

@typing.type_check_only
class ListJobsResponse(typing_extensions.TypedDict, total=False):
    jobs: _list[Job]
    metadata: ResponseMetadata
    nextPageToken: str

@typing.type_check_only
class LocationFilter(typing_extensions.TypedDict, total=False):
    distanceInMiles: float
    isTelecommute: bool
    latLng: LatLng
    name: str
    regionCode: str

@typing.type_check_only
class MatchingJob(typing_extensions.TypedDict, total=False):
    commuteInfo: CommuteInfo
    job: Job
    jobSummary: str
    jobTitleSnippet: str
    searchTextSnippet: str

@typing.type_check_only
class MendelDebugInput(typing_extensions.TypedDict, total=False):
    namespacedDebugInput: dict[str, typing.Any]

@typing.type_check_only
class Money(typing_extensions.TypedDict, total=False):
    currencyCode: str
    nanos: int
    units: str

@typing.type_check_only
class NamespacedDebugInput(typing_extensions.TypedDict, total=False):
    absolutelyForcedExpNames: _list[str]
    absolutelyForcedExpTags: _list[str]
    absolutelyForcedExps: _list[int]
    conditionallyForcedExpNames: _list[str]
    conditionallyForcedExpTags: _list[str]
    conditionallyForcedExps: _list[int]
    disableAutomaticEnrollmentSelection: bool
    disableExpNames: _list[str]
    disableExpTags: _list[str]
    disableExps: _list[int]
    disableManualEnrollmentSelection: bool
    disableOrganicSelection: bool
    forcedFlags: dict[str, typing.Any]
    forcedRollouts: dict[str, typing.Any]

@typing.type_check_only
class NumericBucketingOption(typing_extensions.TypedDict, total=False):
    bucketBounds: _list[float]
    requiresMinMax: bool

@typing.type_check_only
class NumericBucketingResult(typing_extensions.TypedDict, total=False):
    counts: _list[BucketizedCount]
    maxValue: float
    minValue: float

@typing.type_check_only
class PostalAddress(typing_extensions.TypedDict, total=False):
    addressLines: _list[str]
    administrativeArea: str
    languageCode: str
    locality: str
    organization: str
    postalCode: str
    recipients: _list[str]
    regionCode: str
    revision: int
    sortingCode: str
    sublocality: str

@typing.type_check_only
class RequestMetadata(typing_extensions.TypedDict, total=False):
    deviceInfo: DeviceInfo
    domain: str
    sessionId: str
    userId: str

@typing.type_check_only
class ResponseMetadata(typing_extensions.TypedDict, total=False):
    experimentIdList: _list[int]
    mode: typing_extensions.Literal[
        "SEARCH_MODE_UNSPECIFIED",
        "JOB_SEARCH",
        "FEATURED_JOB_SEARCH",
        "EMAIL_ALERT_SEARCH",
    ]
    requestId: str

@typing.type_check_only
class SearchJobsRequest(typing_extensions.TypedDict, total=False):
    disableRelevanceThresholding: bool
    enableBroadening: bool
    enablePreciseResultSize: bool
    filters: JobFilters
    histogramFacets: HistogramFacets
    jobView: typing_extensions.Literal[
        "JOB_VIEW_UNSPECIFIED", "SMALL", "MINIMAL", "FULL"
    ]
    mode: typing_extensions.Literal[
        "SEARCH_MODE_UNSPECIFIED",
        "JOB_SEARCH",
        "FEATURED_JOB_SEARCH",
        "EMAIL_ALERT_SEARCH",
    ]
    offset: int
    orderBy: typing_extensions.Literal[
        "SORT_BY_UNSPECIFIED",
        "RELEVANCE_DESC",
        "PUBLISHED_DATE_DESC",
        "UPDATED_DATE_DESC",
        "TITLE",
        "TITLE_DESC",
        "ANNUALIZED_BASE_COMPENSATION",
        "ANNUALIZED_TOTAL_COMPENSATION",
        "ANNUALIZED_BASE_COMPENSATION_DESC",
        "ANNUALIZED_TOTAL_COMPENSATION_DESC",
    ]
    pageSize: int
    pageToken: str
    query: JobQuery
    requestMetadata: RequestMetadata
    sortBy: typing_extensions.Literal[
        "SORT_BY_UNSPECIFIED",
        "RELEVANCE_DESC",
        "PUBLISHED_DATE_DESC",
        "UPDATED_DATE_DESC",
        "TITLE",
        "TITLE_DESC",
        "ANNUALIZED_BASE_COMPENSATION",
        "ANNUALIZED_TOTAL_COMPENSATION",
        "ANNUALIZED_BASE_COMPENSATION_DESC",
        "ANNUALIZED_TOTAL_COMPENSATION_DESC",
    ]

@typing.type_check_only
class SearchJobsResponse(typing_extensions.TypedDict, total=False):
    appliedCommuteFilter: CommutePreference
    appliedJobLocationFilters: _list[JobLocation]
    estimatedTotalSize: str
    histogramResults: HistogramResults
    jobView: typing_extensions.Literal[
        "JOB_VIEW_UNSPECIFIED", "SMALL", "MINIMAL", "FULL"
    ]
    matchingJobs: _list[MatchingJob]
    metadata: ResponseMetadata
    nextPageToken: str
    numJobsFromBroadenedQuery: int
    spellResult: SpellingCorrection
    totalSize: str

@typing.type_check_only
class SpellingCorrection(typing_extensions.TypedDict, total=False):
    corrected: bool
    correctedText: str

@typing.type_check_only
class Status(typing_extensions.TypedDict, total=False):
    code: int
    details: _list[dict[str, typing.Any]]
    message: str

@typing.type_check_only
class StringValues(typing_extensions.TypedDict, total=False):
    values: _list[str]

@typing.type_check_only
class UpdateJobRequest(typing_extensions.TypedDict, total=False):
    disableStreetAddressResolution: bool
    job: Job
    processingOptions: JobProcessingOptions
    updateJobFields: str
